@@ -16,6 +16,9 @@
  */
 package org.apache.lucene.search;
 
+import static org.apache.lucene.util.RamUsageEstimator.HASHTABLE_RAM_BYTES_PER_ENTRY;
+import static org.apache.lucene.util.RamUsageEstimator.LINKED_HASHTABLE_RAM_BYTES_PER_ENTRY;
+import static org.apache.lucene.util.RamUsageEstimator.QUERY_DEFAULT_RAM_BYTES_USED;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -31,37 +34,31 @@ import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.function.Predicate;
-
 import org.apache.lucene.index.IndexReader;
 import org.apache.lucene.index.IndexReaderContext;
 import org.apache.lucene.index.LeafReaderContext;
 import org.apache.lucene.index.ReaderUtil;
-import org.apache.lucene.index.Term;
 import org.apache.lucene.index.TieredMergePolicy;
 import org.apache.lucene.util.Accountable;
 import org.apache.lucene.util.Accountables;
 import org.apache.lucene.util.BitDocIdSet;
 import org.apache.lucene.util.FixedBitSet;
+import org.apache.lucene.util.RamUsageEstimator;
 import org.apache.lucene.util.RoaringDocIdSet;
 
-import static org.apache.lucene.util.RamUsageEstimator.HASHTABLE_RAM_BYTES_PER_ENTRY;
-import static org.apache.lucene.util.RamUsageEstimator.LINKED_HASHTABLE_RAM_BYTES_PER_ENTRY;
-import static org.apache.lucene.util.RamUsageEstimator.QUERY_DEFAULT_RAM_BYTES_USED;
-
 /**
- * A {@link QueryCache} that evicts queries using a LRU (least-recently-used)
- * eviction policy in order to remain under a given maximum size and number of
- * bytes used.
+ * A {@link QueryCache} that evicts queries using a LRU (least-recently-used) eviction policy in
+ * order to remain under a given maximum size and number of bytes used.
  *
- * This class is thread-safe.
+ * <p>This class is thread-safe.
  *
- * Note that query eviction runs in linear time with the total number of
- * segments that have cache entries so this cache works best with
- * {@link QueryCachingPolicy caching policies} that only cache on "large"
- * segments, and it is advised to not share this cache across too many indices.
+ * <p>Note that query eviction runs in linear time with the total number of segments that have cache
+ * entries so this cache works best with {@link QueryCachingPolicy caching policies} that only cache
+ * on "large" segments, and it is advised to not share this cache across too many indices.
+ *
+ * <p>A default query cache and policy instance is used in IndexSearcher. If you want to replace
+ * those defaults it is typically done like this:
  *
- * A default query cache and policy instance is used in IndexSearcher. If you want to replace those defaults
- * it is typically done like this:
  * <pre class="prettyprint">
  *   final int maxNumberOfCachedQueries = 256;
  *   final long maxRamBytesUsed = 50 * 1024L * 1024L; // 50MB
@@ -73,17 +70,15 @@ import static org.apache.lucene.util.RamUsageEstimator.QUERY_DEFAULT_RAM_BYTES_U
  *   indexSearcher.setQueryCachingPolicy(defaultCachingPolicy);
  * </pre>
  *
- * This cache exposes some global statistics ({@link #getHitCount() hit count},
- * {@link #getMissCount() miss count}, {@link #getCacheSize() number of cache
- * entries}, {@link #getCacheCount() total number of DocIdSets that have ever
- * been cached}, {@link #getEvictionCount() number of evicted entries}). In
- * case you would like to have more fine-grained statistics, such as per-index
- * or per-query-class statistics, it is possible to override various callbacks:
- * {@link #onHit}, {@link #onMiss},
- * {@link #onQueryCache}, {@link #onQueryEviction},
- * {@link #onDocIdSetCache}, {@link #onDocIdSetEviction} and {@link #onClear}.
- * It is better to not perform heavy computations in these methods though since
- * they are called synchronously and under a lock.
+ * This cache exposes some global statistics ({@link #getHitCount() hit count}, {@link
+ * #getMissCount() miss count}, {@link #getCacheSize() number of cache entries}, {@link
+ * #getCacheCount() total number of DocIdSets that have ever been cached}, {@link
+ * #getEvictionCount() number of evicted entries}). In case you would like to have more fine-grained
+ * statistics, such as per-index or per-query-class statistics, it is possible to override various
+ * callbacks: {@link #onHit}, {@link #onMiss}, {@link #onQueryCache}, {@link #onQueryEviction},
+ * {@link #onDocIdSetCache}, {@link #onDocIdSetEviction} and {@link #onClear}. It is better to not
+ * perform heavy computations in these methods though since they are called synchronously and under
+ * a lock.
  *
  * @see QueryCachingPolicy
  * @lucene.experimental
@@ -113,20 +108,24 @@ public class LRUQueryCache implements QueryCache, Accountable {
   private volatile long cacheSize;
 
   /**
-   * Expert: Create a new instance that will cache at most <code>maxSize</code>
-   * queries with at most <code>maxRamBytesUsed</code> bytes of memory, only on
-   * leaves that satisfy {@code leavesToCache}.
+   * Expert: Create a new instance that will cache at most <code>maxSize</code> queries with at most
+   * <code>maxRamBytesUsed</code> bytes of memory, only on leaves that satisfy {@code
+   * leavesToCache}.
    *
-   * Also, clauses whose cost is {@code skipCacheFactor} times more than the cost of the top-level query
-   * will not be cached in order to not slow down queries too much.
+   * <p>Also, clauses whose cost is {@code skipCacheFactor} times more than the cost of the
+   * top-level query will not be cached in order to not slow down queries too much.
    */
-  public LRUQueryCache(int maxSize, long maxRamBytesUsed,
-                       Predicate<LeafReaderContext> leavesToCache, float skipCacheFactor) {
+  public LRUQueryCache(
+      int maxSize,
+      long maxRamBytesUsed,
+      Predicate<LeafReaderContext> leavesToCache,
+      float skipCacheFactor) {
     this.maxSize = maxSize;
     this.maxRamBytesUsed = maxRamBytesUsed;
     this.leavesToCache = leavesToCache;
     if (skipCacheFactor >= 1 == false) { // NaN >= 1 evaluates false
-      throw new IllegalArgumentException("skipCacheFactor must be no less than 1, get " + skipCacheFactor);
+      throw new IllegalArgumentException(
+          "skipCacheFactor must be no less than 1, get " + skipCacheFactor);
     }
     this.skipCacheFactor = skipCacheFactor;
 
@@ -138,17 +137,14 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Create a new instance that will cache at most <code>maxSize</code> queries
-   * with at most <code>maxRamBytesUsed</code> bytes of memory. Queries will
-   * only be cached on leaves that have more than 10k documents and have more
-   * than 3% of the total number of documents in the index.
-   * This should guarantee that all leaves from the upper
-   * {@link TieredMergePolicy tier} will be cached while ensuring that at most
-   * <tt>33</tt> leaves can make it to the cache (very likely less than 10 in
-   * practice), which is useful for this implementation since some operations
-   * perform in linear time with the number of cached leaves.
-   * Only clauses whose cost is at most 100x the cost of the top-level query will
-   * be cached in order to not hurt latency too much because of caching.
+   * Create a new instance that will cache at most <code>maxSize</code> queries with at most <code>
+   * maxRamBytesUsed</code> bytes of memory. Queries will only be cached on leaves that have more
+   * than 10k documents and have more than 3% of the total number of documents in the index. This
+   * should guarantee that all leaves from the upper {@link TieredMergePolicy tier} will be cached
+   * while ensuring that at most <code>33</code> leaves can make it to the cache (very likely less
+   * than 10 in practice), which is useful for this implementation since some operations perform in
+   * linear time with the number of cached leaves. Only clauses whose cost is at most 100x the cost
+   * of the top-level query will be cached in order to not hurt latency too much because of caching.
    */
   public LRUQueryCache(int maxSize, long maxRamBytesUsed) {
     this(maxSize, maxRamBytesUsed, new MinSegmentSizePredicate(10000, .03f), 10);
@@ -177,9 +173,9 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Expert: callback when there is a cache hit on a given query.
-   * Implementing this method is typically useful in order to compute more
-   * fine-grained statistics about the query cache.
+   * Expert: callback when there is a cache hit on a given query. Implementing this method is
+   * typically useful in order to compute more fine-grained statistics about the query cache.
+   *
    * @see #onMiss
    * @lucene.experimental
    */
@@ -190,6 +186,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
 
   /**
    * Expert: callback when there is a cache miss on a given query.
+   *
    * @see #onHit
    * @lucene.experimental
    */
@@ -200,9 +197,9 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Expert: callback when a query is added to this cache.
-   * Implementing this method is typically useful in order to compute more
-   * fine-grained statistics about the query cache.
+   * Expert: callback when a query is added to this cache. Implementing this method is typically
+   * useful in order to compute more fine-grained statistics about the query cache.
+   *
    * @see #onQueryEviction
    * @lucene.experimental
    */
@@ -213,6 +210,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
 
   /**
    * Expert: callback when a query is evicted from this cache.
+   *
    * @see #onQueryCache
    * @lucene.experimental
    */
@@ -222,9 +220,9 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Expert: callback when a {@link DocIdSet} is added to this cache.
-   * Implementing this method is typically useful in order to compute more
-   * fine-grained statistics about the query cache.
+   * Expert: callback when a {@link DocIdSet} is added to this cache. Implementing this method is
+   * typically useful in order to compute more fine-grained statistics about the query cache.
+   *
    * @see #onDocIdSetEviction
    * @lucene.experimental
    */
@@ -236,8 +234,8 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Expert: callback when one or more {@link DocIdSet}s are removed from this
-   * cache.
+   * Expert: callback when one or more {@link DocIdSet}s are removed from this cache.
+   *
    * @see #onDocIdSetCache
    * @lucene.experimental
    */
@@ -249,6 +247,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
 
   /**
    * Expert: callback when the cache is completely cleared.
+   *
    * @lucene.experimental
    */
   protected void onClear() {
@@ -268,7 +267,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
     }
   }
 
-  DocIdSet get(Query key, IndexReader.CacheHelper cacheHelper) {
+  CacheAndCount get(Query key, IndexReader.CacheHelper cacheHelper) {
     assert lock.isHeldByCurrentThread();
     assert key instanceof BoostQuery == false;
     assert key instanceof ConstantScoreQuery == false;
@@ -284,7 +283,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
       onMiss(readerKey, key);
       return null;
     }
-    final DocIdSet cached = leafCache.get(singleton);
+    final CacheAndCount cached = leafCache.get(singleton);
     if (cached == null) {
       onMiss(readerKey, singleton);
     } else {
@@ -293,7 +292,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
     return cached;
   }
 
-  private void putIfAbsent(Query query, DocIdSet set, IndexReader.CacheHelper cacheHelper) {
+  private void putIfAbsent(Query query, CacheAndCount cached, IndexReader.CacheHelper cacheHelper) {
     assert query instanceof BoostQuery == false;
     assert query instanceof ConstantScoreQuery == false;
     // under a lock to make sure that mostRecentlyUsedQueries and cache remain sync'ed
@@ -320,7 +319,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
         // we just created a new leaf cache, need to register a close listener
         cacheHelper.addClosedListener(this::clearCoreCacheKey);
       }
-      leafCache.putIfAbsent(query, set);
+      leafCache.putIfAbsent(query, cached);
       evictIfNecessary();
     } finally {
       lock.unlock();
@@ -340,19 +339,21 @@ public class LRUQueryCache implements QueryCache, Accountable {
         if (size == mostRecentlyUsedQueries.size()) {
           // size did not decrease, because the hash of the query changed since it has been
           // put into the cache
-          throw new ConcurrentModificationException("Removal from the cache failed! This " +
-              "is probably due to a query which has been modified after having been put into " +
-              " the cache or a badly implemented clone(). Query class: [" + query.getClass() +
-              "], query: [" + query + "]");
+          throw new ConcurrentModificationException(
+              "Removal from the cache failed! This "
+                  + "is probably due to a query which has been modified after having been put into "
+                  + " the cache or a badly implemented clone(). Query class: ["
+                  + query.getClass()
+                  + "], query: ["
+                  + query
+                  + "]");
         }
         onEviction(query);
       } while (iterator.hasNext() && requiresEviction());
     }
   }
 
-  /**
-   * Remove all cache entries for the given core cache key.
-   */
+  /** Remove all cache entries for the given core cache key. */
   public void clearCoreCacheKey(Object coreKey) {
     lock.lock();
     try {
@@ -372,9 +373,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
     }
   }
 
-  /**
-   * Remove all cache entries for the given query.
-   */
+  /** Remove all cache entries for the given query. */
   public void clearQuery(Query query) {
     lock.lock();
     try {
@@ -395,14 +394,13 @@ public class LRUQueryCache implements QueryCache, Accountable {
     }
   }
 
-  /**
-   * Clear the content of this cache.
-   */
+  /** Clear the content of this cache. */
   public void clear() {
     lock.lock();
     try {
       cache.clear();
-      // Note that this also clears the uniqueQueries map since mostRecentlyUsedQueries is the uniqueQueries.keySet view:
+      // Note that this also clears the uniqueQueries map since mostRecentlyUsedQueries is the
+      // uniqueQueries.keySet view:
       mostRecentlyUsedQueries.clear();
       onClear();
     } finally {
@@ -415,29 +413,38 @@ public class LRUQueryCache implements QueryCache, Accountable {
     lock.lock();
     try {
       if (requiresEviction()) {
-        throw new AssertionError("requires evictions: size=" + mostRecentlyUsedQueries.size()
-            + ", maxSize=" + maxSize + ", ramBytesUsed=" + ramBytesUsed() + ", maxRamBytesUsed=" + maxRamBytesUsed);
+        throw new AssertionError(
+            "requires evictions: size="
+                + mostRecentlyUsedQueries.size()
+                + ", maxSize="
+                + maxSize
+                + ", ramBytesUsed="
+                + ramBytesUsed()
+                + ", maxRamBytesUsed="
+                + maxRamBytesUsed);
       }
       for (LeafCache leafCache : cache.values()) {
         Set<Query> keys = Collections.newSetFromMap(new IdentityHashMap<>());
         keys.addAll(leafCache.cache.keySet());
         keys.removeAll(mostRecentlyUsedQueries);
         if (!keys.isEmpty()) {
-          throw new AssertionError("One leaf cache contains more keys than the top-level cache: " + keys);
+          throw new AssertionError(
+              "One leaf cache contains more keys than the top-level cache: " + keys);
         }
       }
       long recomputedRamBytesUsed =
-            HASHTABLE_RAM_BYTES_PER_ENTRY * cache.size()
-          + LINKED_HASHTABLE_RAM_BYTES_PER_ENTRY * uniqueQueries.size();
+          HASHTABLE_RAM_BYTES_PER_ENTRY * cache.size()
+              + LINKED_HASHTABLE_RAM_BYTES_PER_ENTRY * uniqueQueries.size();
       recomputedRamBytesUsed += mostRecentlyUsedQueries.size() * QUERY_DEFAULT_RAM_BYTES_USED;
       for (LeafCache leafCache : cache.values()) {
         recomputedRamBytesUsed += HASHTABLE_RAM_BYTES_PER_ENTRY * leafCache.cache.size();
-        for (DocIdSet set : leafCache.cache.values()) {
-          recomputedRamBytesUsed += set.ramBytesUsed();
+        for (CacheAndCount cached : leafCache.cache.values()) {
+          recomputedRamBytesUsed += cached.ramBytesUsed();
         }
       }
       if (recomputedRamBytesUsed != ramBytesUsed) {
-        throw new AssertionError("ramBytesUsed mismatch : " + ramBytesUsed + " != " + recomputedRamBytesUsed);
+        throw new AssertionError(
+            "ramBytesUsed mismatch : " + ramBytesUsed + " != " + recomputedRamBytesUsed);
       }
 
       long recomputedCacheSize = 0;
@@ -445,7 +452,8 @@ public class LRUQueryCache implements QueryCache, Accountable {
         recomputedCacheSize += leafCache.cache.size();
       }
       if (recomputedCacheSize != getCacheSize()) {
-        throw new AssertionError("cacheSize mismatch : " + getCacheSize() + " != " + recomputedCacheSize);
+        throw new AssertionError(
+            "cacheSize mismatch : " + getCacheSize() + " != " + recomputedCacheSize);
       }
     } finally {
       lock.unlock();
@@ -488,11 +496,10 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Default cache implementation: uses {@link RoaringDocIdSet} for sets that
-   * have a density &lt; 1% and a {@link BitDocIdSet} over a {@link FixedBitSet}
-   * otherwise.
+   * Default cache implementation: uses {@link RoaringDocIdSet} for sets that have a density &lt; 1%
+   * and a {@link BitDocIdSet} over a {@link FixedBitSet} otherwise.
    */
-  protected DocIdSet cacheImpl(BulkScorer scorer, int maxDoc) throws IOException {
+  protected CacheAndCount cacheImpl(BulkScorer scorer, int maxDoc) throws IOException {
     if (scorer.cost() * 100 >= maxDoc) {
       // FixedBitSet is faster for dense sets and will enable the random-access
       // optimization in ConjunctionDISI
@@ -502,47 +509,51 @@ public class LRUQueryCache implements QueryCache, Accountable {
     }
   }
 
-  private static DocIdSet cacheIntoBitSet(BulkScorer scorer, int maxDoc) throws IOException {
+  private static CacheAndCount cacheIntoBitSet(BulkScorer scorer, int maxDoc) throws IOException {
     final FixedBitSet bitSet = new FixedBitSet(maxDoc);
-    long cost[] = new long[1];
-    scorer.score(new LeafCollector() {
+    int[] count = new int[1];
+    scorer.score(
+        new LeafCollector() {
 
-      @Override
-      public void setScorer(Scorable scorer) throws IOException {}
+          @Override
+          public void setScorer(Scorable scorer) throws IOException {}
 
-      @Override
-      public void collect(int doc) throws IOException {
-        cost[0]++;
-        bitSet.set(doc);
-      }
-
-    }, null);
-    return new BitDocIdSet(bitSet, cost[0]);
+          @Override
+          public void collect(int doc) throws IOException {
+            count[0]++;
+            bitSet.set(doc);
+          }
+        },
+        null);
+    return new CacheAndCount(new BitDocIdSet(bitSet, count[0]), count[0]);
   }
 
-  private static DocIdSet cacheIntoRoaringDocIdSet(BulkScorer scorer, int maxDoc) throws IOException {
+  private static CacheAndCount cacheIntoRoaringDocIdSet(BulkScorer scorer, int maxDoc)
+      throws IOException {
     RoaringDocIdSet.Builder builder = new RoaringDocIdSet.Builder(maxDoc);
-    scorer.score(new LeafCollector() {
+    scorer.score(
+        new LeafCollector() {
 
-      @Override
-      public void setScorer(Scorable scorer) throws IOException {}
+          @Override
+          public void setScorer(Scorable scorer) throws IOException {}
 
-      @Override
-      public void collect(int doc) throws IOException {
-        builder.add(doc);
-      }
-
-    }, null);
-    return builder.build();
+          @Override
+          public void collect(int doc) throws IOException {
+            builder.add(doc);
+          }
+        },
+        null);
+    RoaringDocIdSet cache = builder.build();
+    return new CacheAndCount(cache, cache.cardinality());
   }
 
   /**
-   * Return the total number of times that a {@link Query} has been looked up
-   * in this {@link QueryCache}. Note that this number is incremented once per
-   * segment so running a cached query only once will increment this counter
-   * by the number of segments that are wrapped by the searcher.
-   * Note that by definition, {@link #getTotalCount()} is the sum of
-   * {@link #getHitCount()} and {@link #getMissCount()}.
+   * Return the total number of times that a {@link Query} has been looked up in this {@link
+   * QueryCache}. Note that this number is incremented once per segment so running a cached query
+   * only once will increment this counter by the number of segments that are wrapped by the
+   * searcher. Note that by definition, {@link #getTotalCount()} is the sum of {@link
+   * #getHitCount()} and {@link #getMissCount()}.
+   *
    * @see #getHitCount()
    * @see #getMissCount()
    */
@@ -551,9 +562,9 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Over the {@link #getTotalCount() total} number of times that a query has
-   * been looked up, return how many times a cached {@link DocIdSet} has been
-   * found and returned.
+   * Over the {@link #getTotalCount() total} number of times that a query has been looked up, return
+   * how many times a cached {@link DocIdSet} has been found and returned.
+   *
    * @see #getTotalCount()
    * @see #getMissCount()
    */
@@ -562,9 +573,9 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Over the {@link #getTotalCount() total} number of times that a query has
-   * been looked up, return how many times this query was not contained in the
-   * cache.
+   * Over the {@link #getTotalCount() total} number of times that a query has been looked up, return
+   * how many times this query was not contained in the cache.
+   *
    * @see #getTotalCount()
    * @see #getHitCount()
    */
@@ -573,8 +584,8 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Return the total number of {@link DocIdSet}s which are currently stored
-   * in the cache.
+   * Return the total number of {@link DocIdSet}s which are currently stored in the cache.
+   *
    * @see #getCacheCount()
    * @see #getEvictionCount()
    */
@@ -583,11 +594,11 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Return the total number of cache entries that have been generated and put
-   * in the cache. It is highly desirable to have a {@link #getHitCount() hit
-   * count} that is much higher than the {@link #getCacheCount() cache count}
-   * as the opposite would indicate that the query cache makes efforts in order
-   * to cache queries but then they do not get reused.
+   * Return the total number of cache entries that have been generated and put in the cache. It is
+   * highly desirable to have a {@link #getHitCount() hit count} that is much higher than the {@link
+   * #getCacheCount() cache count} as the opposite would indicate that the query cache makes efforts
+   * in order to cache queries but then they do not get reused.
+   *
    * @see #getCacheSize()
    * @see #getEvictionCount()
    */
@@ -596,12 +607,12 @@ public class LRUQueryCache implements QueryCache, Accountable {
   }
 
   /**
-   * Return the number of cache entries that have been removed from the cache
-   * either in order to stay under the maximum configured size/ram usage, or
-   * because a segment has been closed. High numbers of evictions might mean
-   * that queries are not reused or that the {@link QueryCachingPolicy
-   * caching policy} caches too aggressively on NRT segments which get merged
+   * Return the number of cache entries that have been removed from the cache either in order to
+   * stay under the maximum configured size/ram usage, or because a segment has been closed. High
+   * numbers of evictions might mean that queries are not reused or that the {@link
+   * QueryCachingPolicy caching policy} caches too aggressively on NRT segments which get merged
    * early.
+   *
    * @see #getCacheCount()
    * @see #getCacheSize()
    */
@@ -613,7 +624,7 @@ public class LRUQueryCache implements QueryCache, Accountable {
   private class LeafCache implements Accountable {
 
     private final Object key;
-    private final Map<Query, DocIdSet> cache;
+    private final Map<Query, CacheAndCount> cache;
     private volatile long ramBytesUsed;
 
     LeafCache(Object key) {
@@ -632,25 +643,25 @@ public class LRUQueryCache implements QueryCache, Accountable {
       LRUQueryCache.this.onDocIdSetEviction(key, 1, ramBytesUsed);
     }
 
-    DocIdSet get(Query query) {
+    CacheAndCount get(Query query) {
       assert query instanceof BoostQuery == false;
       assert query instanceof ConstantScoreQuery == false;
       return cache.get(query);
     }
 
-    void putIfAbsent(Query query, DocIdSet set) {
+    void putIfAbsent(Query query, CacheAndCount cached) {
       assert query instanceof BoostQuery == false;
       assert query instanceof ConstantScoreQuery == false;
-      if (cache.putIfAbsent(query, set) == null) {
+      if (cache.putIfAbsent(query, cached) == null) {
         // the set was actually put
-        onDocIdSetCache(HASHTABLE_RAM_BYTES_PER_ENTRY + set.ramBytesUsed());
+        onDocIdSetCache(HASHTABLE_RAM_BYTES_PER_ENTRY + cached.ramBytesUsed());
       }
     }
 
     void remove(Query query) {
       assert query instanceof BoostQuery == false;
       assert query instanceof ConstantScoreQuery == false;
-      DocIdSet removed = cache.remove(query);
+      CacheAndCount removed = cache.remove(query);
       if (removed != null) {
         onDocIdSetEviction(HASHTABLE_RAM_BYTES_PER_ENTRY + removed.ramBytesUsed());
       }
@@ -660,7 +671,6 @@ public class LRUQueryCache implements QueryCache, Accountable {
     public long ramBytesUsed() {
       return ramBytesUsed;
     }
-
   }
 
   private class CachingWrapperWeight extends ConstantScoreWeight {
@@ -678,11 +688,6 @@ public class LRUQueryCache implements QueryCache, Accountable {
       used = new AtomicBoolean(false);
     }
 
-    @Override
-    public void extractTerms(Set<Term> terms) {
-      in.extractTerms(terms);
-    }
-
     @Override
     public Matches matches(LeafReaderContext context, int doc) throws IOException {
       return in.matches(context, doc);
@@ -700,10 +705,10 @@ public class LRUQueryCache implements QueryCache, Accountable {
       return worstCaseRamUsage * 5 < totalRamAvailable;
     }
 
-    private DocIdSet cache(LeafReaderContext context) throws IOException {
+    private CacheAndCount cache(LeafReaderContext context) throws IOException {
       final BulkScorer scorer = in.bulkScorer(context);
       if (scorer == null) {
-        return DocIdSet.EMPTY;
+        return CacheAndCount.EMPTY;
       } else {
         return cacheImpl(scorer, context.reader().maxDoc());
       }
@@ -711,7 +716,8 @@ public class LRUQueryCache implements QueryCache, Accountable {
 
     /** Check whether this segment is eligible for caching, regardless of the query. */
     private boolean shouldCache(LeafReaderContext context) throws IOException {
-      return cacheEntryHasReasonableWorstCaseSize(ReaderUtil.getTopLevelContext(context).reader().maxDoc())
+      return cacheEntryHasReasonableWorstCaseSize(
+              ReaderUtil.getTopLevelContext(context).reader().maxDoc())
           && leavesToCache.test(context);
     }
 
@@ -743,18 +749,18 @@ public class LRUQueryCache implements QueryCache, Accountable {
         return in.scorerSupplier(context);
       }
 
-      DocIdSet docIdSet;
+      CacheAndCount cached;
       try {
-        docIdSet = get(in.getQuery(), cacheHelper);
+        cached = get(in.getQuery(), cacheHelper);
       } finally {
         lock.unlock();
       }
 
-      if (docIdSet == null) {
+      if (cached == null) {
         if (policy.shouldCache(in.getQuery())) {
           final ScorerSupplier supplier = in.scorerSupplier(context);
           if (supplier == null) {
-            putIfAbsent(in.getQuery(), DocIdSet.EMPTY, cacheHelper);
+            putIfAbsent(in.getQuery(), CacheAndCount.EMPTY, cacheHelper);
             return null;
           }
 
@@ -768,15 +774,18 @@ public class LRUQueryCache implements QueryCache, Accountable {
               }
 
               Scorer scorer = supplier.get(Long.MAX_VALUE);
-              DocIdSet docIdSet = cacheImpl(new DefaultBulkScorer(scorer), context.reader().maxDoc());
-              putIfAbsent(in.getQuery(), docIdSet, cacheHelper);
-              DocIdSetIterator disi = docIdSet.iterator();
+              CacheAndCount cached =
+                  cacheImpl(new DefaultBulkScorer(scorer), context.reader().maxDoc());
+              putIfAbsent(in.getQuery(), cached, cacheHelper);
+              DocIdSetIterator disi = cached.iterator();
               if (disi == null) {
-                // docIdSet.iterator() is allowed to return null when empty but we want a non-null iterator here
+                // docIdSet.iterator() is allowed to return null when empty but we want a non-null
+                // iterator here
                 disi = DocIdSetIterator.empty();
               }
 
-              return new ConstantScoreScorer(CachingWrapperWeight.this, 0f, ScoreMode.COMPLETE_NO_SCORES, disi);
+              return new ConstantScoreScorer(
+                  CachingWrapperWeight.this, 0f, ScoreMode.COMPLETE_NO_SCORES, disi);
             }
 
             @Override
@@ -789,11 +798,11 @@ public class LRUQueryCache implements QueryCache, Accountable {
         }
       }
 
-      assert docIdSet != null;
-      if (docIdSet == DocIdSet.EMPTY) {
+      assert cached != null;
+      if (cached == CacheAndCount.EMPTY) {
         return null;
       }
-      final DocIdSetIterator disi = docIdSet.iterator();
+      final DocIdSetIterator disi = cached.iterator();
       if (disi == null) {
         return null;
       }
@@ -801,7 +810,8 @@ public class LRUQueryCache implements QueryCache, Accountable {
       return new ScorerSupplier() {
         @Override
         public Scorer get(long LeadCost) throws IOException {
-          return new ConstantScoreScorer(CachingWrapperWeight.this, 0f, ScoreMode.COMPLETE_NO_SCORES, disi);
+          return new ConstantScoreScorer(
+              CachingWrapperWeight.this, 0f, ScoreMode.COMPLETE_NO_SCORES, disi);
         }
 
         @Override
@@ -809,7 +819,6 @@ public class LRUQueryCache implements QueryCache, Accountable {
           return disi.cost();
         }
       };
-
     }
 
     @Override
@@ -821,6 +830,59 @@ public class LRUQueryCache implements QueryCache, Accountable {
       return scorerSupplier.get(Long.MAX_VALUE);
     }
 
+    @Override
+    public int count(LeafReaderContext context) throws IOException {
+      // If the wrapped weight can count quickly then use that
+      int innerCount = in.count(context);
+      if (innerCount != -1) {
+        return innerCount;
+      }
+
+      // Our cache won't have an accurate count if there are deletions
+      if (context.reader().hasDeletions()) {
+        return -1;
+      }
+
+      // Otherwise check if the count is in the cache
+      if (used.compareAndSet(false, true)) {
+        policy.onUse(getQuery());
+      }
+
+      if (in.isCacheable(context) == false) {
+        // this segment is not suitable for caching
+        return -1;
+      }
+
+      // Short-circuit: Check whether this segment is eligible for caching
+      // before we take a lock because of #get
+      if (shouldCache(context) == false) {
+        return -1;
+      }
+
+      final IndexReader.CacheHelper cacheHelper = context.reader().getCoreCacheHelper();
+      if (cacheHelper == null) {
+        // this reader has no cacheHelper
+        return -1;
+      }
+
+      // If the lock is already busy, prefer using the uncached version than waiting
+      if (lock.tryLock() == false) {
+        return -1;
+      }
+
+      CacheAndCount cached;
+      try {
+        cached = get(in.getQuery(), cacheHelper);
+      } finally {
+        lock.unlock();
+      }
+      if (cached == null) {
+        // Not cached
+        return -1;
+      }
+      return cached.count();
+    }
+
     @Override
     public boolean isCacheable(LeafReaderContext ctx) {
       return in.isCacheable(ctx);
@@ -854,33 +916,61 @@ public class LRUQueryCache implements QueryCache, Accountable {
         return in.bulkScorer(context);
       }
 
-      DocIdSet docIdSet;
+      CacheAndCount cached;
       try {
-        docIdSet = get(in.getQuery(), cacheHelper);
+        cached = get(in.getQuery(), cacheHelper);
       } finally {
         lock.unlock();
       }
 
-      if (docIdSet == null) {
+      if (cached == null) {
         if (policy.shouldCache(in.getQuery())) {
-          docIdSet = cache(context);
-          putIfAbsent(in.getQuery(), docIdSet, cacheHelper);
+          cached = cache(context);
+          putIfAbsent(in.getQuery(), cached, cacheHelper);
         } else {
           return in.bulkScorer(context);
         }
       }
 
-      assert docIdSet != null;
-      if (docIdSet == DocIdSet.EMPTY) {
+      assert cached != null;
+      if (cached == CacheAndCount.EMPTY) {
         return null;
       }
-      final DocIdSetIterator disi = docIdSet.iterator();
+      final DocIdSetIterator disi = cached.iterator();
       if (disi == null) {
         return null;
       }
 
-      return new DefaultBulkScorer(new ConstantScoreScorer(this, 0f, ScoreMode.COMPLETE_NO_SCORES, disi));
+      return new DefaultBulkScorer(
+          new ConstantScoreScorer(this, 0f, ScoreMode.COMPLETE_NO_SCORES, disi));
+    }
+  }
+
+  /** Cache of doc ids with a count. */
+  protected static class CacheAndCount implements Accountable {
+    protected static final CacheAndCount EMPTY = new CacheAndCount(DocIdSet.EMPTY, 0);
+
+    private static final long BASE_RAM_BYTES_USED =
+        RamUsageEstimator.shallowSizeOfInstance(CacheAndCount.class);
+    private final DocIdSet cache;
+    private final int count;
+
+    public CacheAndCount(DocIdSet cache, int count) {
+      this.cache = cache;
+      this.count = count;
     }
 
+    public DocIdSetIterator iterator() throws IOException {
+      return cache.iterator();
+    }
+
+    public int count() {
+      return count;
+    }
+
+    @Override
+    public long ramBytesUsed() {
+      return BASE_RAM_BYTES_USED + cache.ramBytesUsed();
+    }
   }
 }
