@@ -16,7 +16,6 @@
  */
 package org.apache.lucene.index;
 
-
 import java.io.IOException;
 import java.util.concurrent.BrokenBarrierException;
 import java.util.concurrent.CyclicBarrier;
@@ -25,8 +24,6 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
-
-import org.apache.lucene.analysis.MockAnalyzer;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.FieldType;
@@ -35,31 +32,29 @@ import org.apache.lucene.document.StringField;
 import org.apache.lucene.document.TextField;
 import org.apache.lucene.search.DocIdSetIterator;
 import org.apache.lucene.store.AlreadyClosedException;
-import org.apache.lucene.store.BaseDirectoryWrapper;
 import org.apache.lucene.store.Directory;
 import org.apache.lucene.store.LockObtainFailedException;
-import org.apache.lucene.store.MockDirectoryWrapper;
+import org.apache.lucene.tests.analysis.MockAnalyzer;
+import org.apache.lucene.tests.index.RandomIndexWriter;
+import org.apache.lucene.tests.index.SuppressingConcurrentMergeScheduler;
+import org.apache.lucene.tests.store.BaseDirectoryWrapper;
+import org.apache.lucene.tests.store.MockDirectoryWrapper;
+import org.apache.lucene.tests.util.LineFileDocs;
+import org.apache.lucene.tests.util.LuceneTestCase;
+import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.Bits;
 import org.apache.lucene.util.BytesRef;
-import org.apache.lucene.util.LineFileDocs;
-import org.apache.lucene.util.LuceneTestCase;
-import org.apache.lucene.util.TestUtil;
 import org.apache.lucene.util.ThreadInterruptedException;
-import org.apache.lucene.util.LuceneTestCase.Slow;
 
-/**
- * MultiThreaded IndexWriter tests
- */
-@Slow
+/** MultiThreaded IndexWriter tests */
+@LuceneTestCase.SuppressCodecs("SimpleText")
 public class TestIndexWriterWithThreads extends LuceneTestCase {
 
   // Used by test cases below
   private static class IndexerThread extends Thread {
 
     private final CyclicBarrier syncStart;
-    boolean diskFull;
     Throwable error;
-    AlreadyClosedException ace;
     IndexWriter writer;
     boolean noErrors;
     volatile int addCount;
@@ -84,7 +79,7 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
       customType.setStoreTermVectors(true);
       customType.setStoreTermVectorPositions(true);
       customType.setStoreTermVectorOffsets(true);
-      
+
       doc.add(newField("field", "aaa bbb ccc ddd eee fff ggg hhh iii jjj", customType));
       doc.add(new NumericDocValuesField("dv", 5));
 
@@ -93,34 +88,35 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
 
       do {
         try {
-          writer.updateDocument(new Term("id", ""+(idUpto++)), doc);
+          writer.updateDocument(new Term("id", "" + (idUpto++)), doc);
           addCount++;
         } catch (IOException ioe) {
           if (VERBOSE) {
             System.out.println("TEST: expected exc:");
             ioe.printStackTrace(System.out);
           }
-          //System.out.println(Thread.currentThread().getName() + ": hit exc");
-          //ioe.printStackTrace(System.out);
-          if (ioe.getMessage().startsWith("fake disk full at") ||
-              ioe.getMessage().equals("now failing on purpose")) {
-            diskFull = true;
+          // System.out.println(Thread.currentThread().getName() + ": hit exc");
+          // ioe.printStackTrace(System.out);
+          if (ioe.getMessage().startsWith("fake disk full at")
+              || ioe.getMessage().equals("now failing on purpose")) {
             try {
               Thread.sleep(1);
             } catch (InterruptedException ie) {
               throw new ThreadInterruptedException(ie);
             }
-            if (fullCount++ >= 5)
-              break;
+            if (fullCount++ >= 5) break;
           } else {
             if (noErrors) {
-              System.out.println(Thread.currentThread().getName() + ": ERROR: unexpected IOException:");
+              System.out.println(
+                  Thread.currentThread().getName() + ": ERROR: unexpected IOException:");
               ioe.printStackTrace(System.out);
               error = ioe;
             }
             break;
           }
-        } catch (AlreadyClosedException ace) {
+        } catch (
+            @SuppressWarnings("unused")
+            IllegalStateException ise) {
           // OK: abort closes the writer
           break;
         } catch (Throwable t) {
@@ -136,27 +132,27 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
   }
 
   // LUCENE-1130: make sure immediate disk full on creating
-  // an IndexWriter (hit during DW.ThreadState.init()), with
+  // an IndexWriter (hit during DWPT#updateDocuments()), with
   // multiple threads, is OK:
   public void testImmediateDiskFullWithThreads() throws Exception {
 
     int NUM_THREADS = 3;
-    final int numIterations = TEST_NIGHTLY ? 10 : 3;
-    for (int iter=0;iter<numIterations;iter++) {
+    final int numIterations = TEST_NIGHTLY ? 10 : 1;
+    for (int iter = 0; iter < numIterations; iter++) {
       if (VERBOSE) {
         System.out.println("\nTEST: iter=" + iter);
       }
       MockDirectoryWrapper dir = newMockDirectory();
-      IndexWriter writer = new IndexWriter(
-          dir,
-          newIndexWriterConfig(new MockAnalyzer(random()))
-            .setMaxBufferedDocs(2)
-            .setMergeScheduler(new ConcurrentMergeScheduler())
-            .setMergePolicy(newLogMergePolicy(4))
-            .setCommitOnClose(false)
-      );
+      IndexWriter writer =
+          new IndexWriter(
+              dir,
+              newIndexWriterConfig(new MockAnalyzer(random()))
+                  .setMaxBufferedDocs(2)
+                  .setMergeScheduler(new ConcurrentMergeScheduler())
+                  .setMergePolicy(newLogMergePolicy(4))
+                  .setCommitOnClose(false));
       ((ConcurrentMergeScheduler) writer.getConfig().getMergeScheduler()).setSuppressExceptions();
-      dir.setMaxSizeInBytes(4*1024+20*iter);
+      dir.setMaxSizeInBytes(4 * 1024 + 20 * iter);
 
       CyclicBarrier syncStart = new CyclicBarrier(NUM_THREADS + 1);
       IndexerThread[] threads = new IndexerThread[NUM_THREADS];
@@ -178,9 +174,11 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
       dir.setMaxSizeInBytes(0);
       try {
         writer.commit();
-      } catch (AlreadyClosedException ace) {
+      } catch (
+          @SuppressWarnings("unused")
+          AlreadyClosedException ace) {
         // OK: abort closes the writer
-        assertTrue(writer.deleter.isClosed());
+        assertTrue(writer.isDeleterClosed());
       } finally {
         writer.close();
       }
@@ -188,7 +186,6 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
     }
   }
 
-
   // LUCENE-1130: make sure we can close() even while
   // threads are trying to add documents.  Strictly
   // speaking, this isn't valid us of Lucene's APIs, but we
@@ -196,23 +193,22 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
   public void testCloseWithThreads() throws Exception {
     int NUM_THREADS = 3;
     int numIterations = TEST_NIGHTLY ? 7 : 3;
-    for(int iter=0;iter<numIterations;iter++) {
+    for (int iter = 0; iter < numIterations; iter++) {
       if (VERBOSE) {
         System.out.println("\nTEST: iter=" + iter);
       }
       Directory dir = newDirectory();
 
-      IndexWriter writer = new IndexWriter(
-          dir,
-          newIndexWriterConfig(new MockAnalyzer(random()))
-            .setMaxBufferedDocs(10)
-            .setMergeScheduler(new ConcurrentMergeScheduler())
-            .setMergePolicy(newLogMergePolicy(4))
-            .setCommitOnClose(false)
-      );
+      IndexWriter writer =
+          new IndexWriter(
+              dir,
+              newIndexWriterConfig(new MockAnalyzer(random()))
+                  .setMaxBufferedDocs(10)
+                  .setMergeScheduler(new ConcurrentMergeScheduler())
+                  .setMergePolicy(newLogMergePolicy(4))
+                  .setCommitOnClose(false));
       ((ConcurrentMergeScheduler) writer.getConfig().getMergeScheduler()).setSuppressExceptions();
 
-
       CyclicBarrier syncStart = new CyclicBarrier(NUM_THREADS + 1);
       IndexerThread[] threads = new IndexerThread[NUM_THREADS];
       for (int i = 0; i < NUM_THREADS; i++) {
@@ -224,7 +220,7 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
       boolean done = false;
       while (!done) {
         Thread.sleep(100);
-        for(int i=0;i<NUM_THREADS;i++)
+        for (int i = 0; i < NUM_THREADS; i++)
           // only stop when at least one thread has added a doc
           if (threads[i].addCount > 0) {
             done = true;
@@ -244,25 +240,20 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
       }
 
       // Make sure threads that are adding docs are not hung:
-      for(int i=0;i<NUM_THREADS;i++) {
+      for (int i = 0; i < NUM_THREADS; i++) {
         // Without fix for LUCENE-1130: one of the
         // threads will hang
         threads[i].join();
 
         // [DW] this is unreachable once join() returns a thread cannot be alive.
-        if (threads[i].isAlive())
-          fail("thread seems to be hung");
+        if (threads[i].isAlive()) fail("thread seems to be hung");
       }
 
       // Quick test to make sure index is not corrupt:
       IndexReader reader = DirectoryReader.open(dir);
-      PostingsEnum tdocs = TestUtil.docs(random(), reader,
-          "field",
-          new BytesRef("aaa"),
-          null,
-          0);
+      PostingsEnum tdocs = TestUtil.docs(random(), reader, "field", new BytesRef("aaa"), null, 0);
       int count = 0;
-      while(tdocs.nextDoc() != DocIdSetIterator.NO_MORE_DOCS) {
+      while (tdocs.nextDoc() != DocIdSetIterator.NO_MORE_DOCS) {
         count++;
       }
       assertTrue(count > 0);
@@ -284,14 +275,14 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
       }
       MockDirectoryWrapper dir = newMockDirectory();
 
-      IndexWriter writer = new IndexWriter(
-          dir,
-          newIndexWriterConfig(new MockAnalyzer(random()))
-             .setMaxBufferedDocs(2)
-             .setMergeScheduler(new ConcurrentMergeScheduler())
-             .setMergePolicy(newLogMergePolicy(4))
-             .setCommitOnClose(false)
-      );
+      IndexWriter writer =
+          new IndexWriter(
+              dir,
+              newIndexWriterConfig(new MockAnalyzer(random()))
+                  .setMaxBufferedDocs(2)
+                  .setMergeScheduler(new ConcurrentMergeScheduler())
+                  .setMergePolicy(newLogMergePolicy(4))
+                  .setCommitOnClose(false));
       ((ConcurrentMergeScheduler) writer.getConfig().getMergeScheduler()).setSuppressExceptions();
 
       CyclicBarrier syncStart = new CyclicBarrier(NUM_THREADS + 1);
@@ -315,10 +306,14 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
         writer.commit();
         writer.close();
         success = true;
-      } catch (AlreadyClosedException ace) {
+      } catch (
+          @SuppressWarnings("unused")
+          AlreadyClosedException ace) {
         // OK: abort closes the writer
-        assertTrue(writer.deleter.isClosed());
-      } catch (IOException ioe) {
+        assertTrue(writer.isDeleterClosed());
+      } catch (
+          @SuppressWarnings("unused")
+          IOException ioe) {
         writer.rollback();
         failure.clearDoFail();
       }
@@ -328,8 +323,8 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
 
       if (success) {
         IndexReader reader = DirectoryReader.open(dir);
-        final Bits delDocs = MultiFields.getLiveDocs(reader);
-        for(int j=0;j<reader.maxDoc();j++) {
+        final Bits delDocs = MultiBits.getLiveDocs(reader);
+        for (int j = 0; j < reader.maxDoc(); j++) {
           if (delDocs == null || !delDocs.get(j)) {
             reader.document(j);
             reader.getTermVectors(j);
@@ -347,19 +342,22 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
   public void _testSingleThreadFailure(MockDirectoryWrapper.Failure failure) throws IOException {
     MockDirectoryWrapper dir = newMockDirectory();
 
-    IndexWriterConfig iwc = newIndexWriterConfig(new MockAnalyzer(random()))
-      .setMaxBufferedDocs(2)
-      .setMergeScheduler(new ConcurrentMergeScheduler())
-      .setCommitOnClose(false);
+    IndexWriterConfig iwc =
+        newIndexWriterConfig(new MockAnalyzer(random()))
+            .setMaxBufferedDocs(2)
+            .setMergeScheduler(new ConcurrentMergeScheduler())
+            .setCommitOnClose(false);
 
     if (iwc.getMergeScheduler() instanceof ConcurrentMergeScheduler) {
-      iwc.setMergeScheduler(new SuppressingConcurrentMergeScheduler() {
-          @Override
-          protected boolean isOK(Throwable th) {
-            return th instanceof AlreadyClosedException ||
-              (th instanceof IllegalStateException && th.getMessage().contains("this writer hit an unrecoverable error"));
-          }
-        });
+      iwc.setMergeScheduler(
+          new SuppressingConcurrentMergeScheduler() {
+            @Override
+            protected boolean isOK(Throwable th) {
+              return th instanceof AlreadyClosedException
+                  || (th instanceof IllegalStateException
+                      && th.getMessage().contains("this writer hit an unrecoverable error"));
+            }
+          });
     }
 
     IndexWriter writer = new IndexWriter(dir, iwc);
@@ -370,76 +368,61 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
     customType.setStoreTermVectorOffsets(true);
     doc.add(newField("field", "aaa bbb ccc ddd eee fff ggg hhh iii jjj", customType));
 
-    for(int i=0;i<6;i++)
-      writer.addDocument(doc);
+    for (int i = 0; i < 6; i++) writer.addDocument(doc);
 
     dir.failOn(failure);
     failure.setDoFail();
-    expectThrows(IOException.class, () -> {
-      writer.addDocument(doc);
-      writer.addDocument(doc);
-      writer.commit();
-    });
+    expectThrows(
+        IOException.class,
+        () -> {
+          writer.addDocument(doc);
+          writer.addDocument(doc);
+          writer.commit();
+        });
 
     failure.clearDoFail();
-    expectThrows(AlreadyClosedException.class, () -> {
-      writer.addDocument(doc);
-      writer.commit();
-      writer.close();
-    });
+    expectThrows(
+        AlreadyClosedException.class,
+        () -> {
+          writer.addDocument(doc);
+          writer.commit();
+          writer.close();
+        });
 
-    assertTrue(writer.deleter.isClosed());
+    assertTrue(writer.isDeleterClosed());
     dir.close();
   }
 
   // Throws IOException during FieldsWriter.flushDocument and during DocumentsWriter.abort
   private static class FailOnlyOnAbortOrFlush extends MockDirectoryWrapper.Failure {
     private boolean onlyOnce;
+
     public FailOnlyOnAbortOrFlush(boolean onlyOnce) {
       this.onlyOnce = onlyOnce;
     }
+
     @Override
-    public void eval(MockDirectoryWrapper dir)  throws IOException {
+    public void eval(MockDirectoryWrapper dir) throws IOException {
 
       // Since we throw exc during abort, eg when IW is
       // attempting to delete files, we will leave
-      // leftovers: 
+      // leftovers:
       dir.setAssertNoUnrefencedFilesOnClose(false);
 
       if (doFail) {
-        StackTraceElement[] trace = new Exception().getStackTrace();
-        boolean sawAbortOrFlushDoc = false;
-        boolean sawClose = false;
-        boolean sawMerge = false;
-        for (int i = 0; i < trace.length; i++) {
-          if (sawAbortOrFlushDoc && sawMerge && sawClose) {
-            break;
-          }
-          if ("abort".equals(trace[i].getMethodName()) ||
-              "finishDocument".equals(trace[i].getMethodName())) {
-            sawAbortOrFlushDoc = true;
-          }
-          if ("merge".equals(trace[i].getMethodName())) {
-            sawMerge = true;
-          }
-          if ("close".equals(trace[i].getMethodName())) {
-            sawClose = true;
-          }
-        }
-        if (sawAbortOrFlushDoc && !sawClose && !sawMerge) {
+        if (callStackContainsAnyOf("abort", "finishDocument")
+            && false == callStackContainsAnyOf("merge", "close")) {
           if (onlyOnce) {
             doFail = false;
           }
-          //System.out.println(Thread.currentThread().getName() + ": now fail");
-          //new Throwable().printStackTrace(System.out);
+          // System.out.println(Thread.currentThread().getName() + ": now fail");
+          // new Throwable().printStackTrace(System.out);
           throw new IOException("now failing on purpose");
         }
       }
     }
   }
 
-
-
   // LUCENE-1130: make sure initial IOException, and then 2nd
   // IOException during rollback(), is OK:
   public void testIOExceptionDuringAbort() throws IOException {
@@ -467,21 +450,20 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
   // Throws IOException during DocumentsWriter.writeSegment
   private static class FailOnlyInWriteSegment extends MockDirectoryWrapper.Failure {
     private boolean onlyOnce;
+
     public FailOnlyInWriteSegment(boolean onlyOnce) {
       this.onlyOnce = onlyOnce;
     }
+
     @Override
-    public void eval(MockDirectoryWrapper dir)  throws IOException {
+    public void eval(MockDirectoryWrapper dir) throws IOException {
       if (doFail) {
-        StackTraceElement[] trace = new Exception().getStackTrace();
-        for (int i = 0; i < trace.length; i++) {
-          if ("flush".equals(trace[i].getMethodName()) && DefaultIndexingChain.class.getName().equals(trace[i].getClassName())) {
-            if (onlyOnce)
-              doFail = false;
-            //System.out.println(Thread.currentThread().getName() + ": NOW FAIL: onlyOnce=" + onlyOnce);
-            //new Throwable().printStackTrace(System.out);
-            throw new IOException("now failing on purpose");
-          }
+        if (callStackContains(IndexingChain.class, "flush")) {
+          if (onlyOnce) doFail = false;
+          // System.out.println(Thread.currentThread().getName() + ": NOW FAIL: onlyOnce=" +
+          // onlyOnce);
+          // new Throwable().printStackTrace(System.out);
+          throw new IOException("now failing on purpose");
         }
       }
     }
@@ -506,47 +488,45 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
   public void testIOExceptionDuringWriteSegmentWithThreadsOnlyOnce() throws Exception {
     _testMultipleThreadsFailure(new FailOnlyInWriteSegment(true));
   }
-  
-  //  LUCENE-3365: Test adding two documents with the same field from two different IndexWriters 
+
+  //  LUCENE-3365: Test adding two documents with the same field from two different IndexWriters
   //  that we attempt to open at the same time.  As long as the first IndexWriter completes
   //  and closes before the second IndexWriter time's out trying to get the Lock,
   //  we should see both documents
   public void testOpenTwoIndexWritersOnDifferentThreads() throws IOException, InterruptedException {
-     try (final Directory dir = newDirectory()) {
-       CyclicBarrier syncStart = new CyclicBarrier(2);
-       DelayedIndexAndCloseRunnable thread1 = new DelayedIndexAndCloseRunnable(dir, syncStart);
-       DelayedIndexAndCloseRunnable thread2 = new DelayedIndexAndCloseRunnable(dir, syncStart);
-       thread1.start();
-       thread2.start();
-       thread1.join();
-       thread2.join();
+    try (final Directory dir = newDirectory()) {
+      CyclicBarrier syncStart = new CyclicBarrier(2);
+      DelayedIndexAndCloseRunnable thread1 = new DelayedIndexAndCloseRunnable(dir, syncStart);
+      DelayedIndexAndCloseRunnable thread2 = new DelayedIndexAndCloseRunnable(dir, syncStart);
+      thread1.start();
+      thread2.start();
+      thread1.join();
+      thread2.join();
 
-       if (thread1.failure instanceof LockObtainFailedException ||
-           thread2.failure instanceof LockObtainFailedException) {
-         // We only care about the situation when the two writers succeeded.
-         return;
-       }
+      if (thread1.failure instanceof LockObtainFailedException
+          || thread2.failure instanceof LockObtainFailedException) {
+        // We only care about the situation when the two writers succeeded.
+        return;
+      }
 
-       assertFalse("Failed due to: " + thread1.failure, thread1.failed);
-       assertFalse("Failed due to: " + thread2.failure, thread2.failed);
+      assertFalse("Failed due to: " + thread1.failure, thread1.failed);
+      assertFalse("Failed due to: " + thread2.failure, thread2.failed);
 
-       // now verify that we have two documents in the index
-       IndexReader reader = DirectoryReader.open(dir);
-       assertEquals("IndexReader should have one document per thread running", 2,
-         reader.numDocs());
+      // now verify that we have two documents in the index
+      IndexReader reader = DirectoryReader.open(dir);
+      assertEquals("IndexReader should have one document per thread running", 2, reader.numDocs());
 
-       reader.close();
-     }
+      reader.close();
+    }
   }
-  
+
   static class DelayedIndexAndCloseRunnable extends Thread {
     private final Directory dir;
     boolean failed = false;
     Throwable failure = null;
     private CyclicBarrier syncStart;
 
-    public DelayedIndexAndCloseRunnable(Directory dir,
-                                        CyclicBarrier syncStart) {
+    public DelayedIndexAndCloseRunnable(Directory dir, CyclicBarrier syncStart) {
       this.dir = dir;
       this.syncStart = syncStart;
     }
@@ -580,7 +560,8 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
     analyzer.setMaxTokenLength(TestUtil.nextInt(random(), 1, IndexWriter.MAX_TERM_LENGTH));
 
     writerRef.set(new IndexWriter(d, newIndexWriterConfig(analyzer)));
-    // Make initial commit so the test doesn't trip "corrupt first commit" when virus checker refuses to delete partial segments_N file:
+    // Make initial commit so the test doesn't trip "corrupt first commit" when virus checker
+    // refuses to delete partial segments_N file:
     writerRef.get().commit();
     final LineFileDocs docs = new LineFileDocs(random());
     final Thread[] threads = new Thread[threadCount];
@@ -588,68 +569,81 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
     final AtomicBoolean failed = new AtomicBoolean();
     final Lock rollbackLock = new ReentrantLock();
     final Lock commitLock = new ReentrantLock();
-    for(int threadID=0;threadID<threadCount;threadID++) {
-      threads[threadID] = new Thread() {
-          @Override
-          public void run() {
-            for(int iter=0;iter<iters && !failed.get();iter++) {
-              //final int x = random().nextInt(5);
-              final int x = random().nextInt(3);
-              try {
-                switch(x) {
-                case 0:
-                  rollbackLock.lock();
-                  if (VERBOSE) {
-                    System.out.println("\nTEST: " + Thread.currentThread().getName() + ": now rollback");
+    for (int threadID = 0; threadID < threadCount; threadID++) {
+      threads[threadID] =
+          new Thread() {
+            @Override
+            public void run() {
+              for (int iter = 0; iter < iters && !failed.get(); iter++) {
+                // final int x = random().nextInt(5);
+                final int x = random().nextInt(3);
+                try {
+                  switch (x) {
+                    case 0:
+                      rollbackLock.lock();
+                      if (VERBOSE) {
+                        System.out.println(
+                            "\nTEST: " + Thread.currentThread().getName() + ": now rollback");
+                      }
+                      try {
+                        writerRef.get().rollback();
+                        if (VERBOSE) {
+                          System.out.println(
+                              "TEST: "
+                                  + Thread.currentThread().getName()
+                                  + ": rollback done; now open new writer");
+                        }
+                        writerRef.set(
+                            new IndexWriter(d, newIndexWriterConfig(new MockAnalyzer(random()))));
+                      } finally {
+                        rollbackLock.unlock();
+                      }
+                      break;
+                    case 1:
+                      commitLock.lock();
+                      if (VERBOSE) {
+                        System.out.println(
+                            "\nTEST: " + Thread.currentThread().getName() + ": now commit");
+                      }
+                      try {
+                        if (random().nextBoolean()) {
+                          writerRef.get().prepareCommit();
+                        }
+                        writerRef.get().commit();
+                      } catch (@SuppressWarnings("unused")
+                          AlreadyClosedException
+                          | NullPointerException ace) {
+                        // ok
+                      } finally {
+                        commitLock.unlock();
+                      }
+                      break;
+                    case 2:
+                      if (VERBOSE) {
+                        System.out.println(
+                            "\nTEST: " + Thread.currentThread().getName() + ": now add");
+                      }
+                      try {
+                        writerRef.get().addDocument(docs.nextDoc());
+                      } catch (@SuppressWarnings("unused")
+                          AlreadyClosedException
+                          | NullPointerException
+                          | AssertionError ace) {
+                        // ok
+                      }
+                      break;
                   }
-                  try {
-                    writerRef.get().rollback();
-                    if (VERBOSE) {
-                      System.out.println("TEST: " + Thread.currentThread().getName() + ": rollback done; now open new writer");
-                    }
-                    writerRef.set(new IndexWriter(d, newIndexWriterConfig(new MockAnalyzer(random()))));
-                  } finally {
-                    rollbackLock.unlock();
-                  }
-                  break;
-                case 1:
-                  commitLock.lock();
-                  if (VERBOSE) {
-                    System.out.println("\nTEST: " + Thread.currentThread().getName() + ": now commit");
-                  }
-                  try {
-                    if (random().nextBoolean()) {
-                      writerRef.get().prepareCommit();
-                    }
-                    writerRef.get().commit();
-                  } catch (AlreadyClosedException | NullPointerException ace) {
-                    // ok
-                  } finally {
-                    commitLock.unlock();
-                  }
-                  break;
-                case 2:
-                  if (VERBOSE) {
-                    System.out.println("\nTEST: " + Thread.currentThread().getName() + ": now add");
-                  }
-                  try {
-                    writerRef.get().addDocument(docs.nextDoc());
-                  } catch (AlreadyClosedException | NullPointerException | AssertionError ace) {
-                    // ok
-                  }
-                  break;
+                } catch (Throwable t) {
+                  failed.set(true);
+                  throw new RuntimeException(t);
                 }
-              } catch (Throwable t) {
-                failed.set(true);
-                throw new RuntimeException(t);
               }
             }
-          }
-        };
+          };
       threads[threadID].start();
     }
 
-    for(int threadID=0;threadID<threadCount;threadID++) {
+    for (int threadID = 0; threadID < threadCount; threadID++) {
       threads[threadID].join();
     }
 
@@ -666,11 +660,17 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
     stressUpdateSingleDocWithThreads(true, rarely());
   }
 
-  public void stressUpdateSingleDocWithThreads(boolean useSoftDeletes, boolean forceMerge) throws Exception{
+  public void stressUpdateSingleDocWithThreads(boolean useSoftDeletes, boolean forceMerge)
+      throws Exception {
     try (Directory dir = newDirectory();
-         RandomIndexWriter writer = new RandomIndexWriter(random(), dir,
-             newIndexWriterConfig().setMaxBufferedDocs(-1).setRAMBufferSizeMB(0.00001), useSoftDeletes)) {
-      Thread[] threads = new Thread[3 + random().nextInt(3)];
+        RandomIndexWriter writer =
+            new RandomIndexWriter(
+                random(),
+                dir,
+                newIndexWriterConfig().setMaxBufferedDocs(-1).setRAMBufferSizeMB(0.00001),
+                useSoftDeletes)) {
+      int numThreads = TEST_NIGHTLY ? 3 + random().nextInt(3) : 3;
+      Thread[] threads = new Thread[numThreads];
       AtomicInteger done = new AtomicInteger(0);
       CyclicBarrier barrier = new CyclicBarrier(threads.length + 1);
       Document doc = new Document();
@@ -678,20 +678,22 @@ public class TestIndexWriterWithThreads extends LuceneTestCase {
       writer.updateDocument(new Term("id", "1"), doc);
       int itersPerThread = 100 + random().nextInt(2000);
       for (int i = 0; i < threads.length; i++) {
-        threads[i] = new Thread(() -> {
-          try {
-            barrier.await();
-            for (int iters = 0; iters < itersPerThread; iters++) {
-              Document d = new Document();
-              d.add(new StringField("id", "1", Field.Store.NO));
-              writer.updateDocument(new Term("id", "1"), d);
-            }
-          } catch (Exception e) {
-            throw new AssertionError(e);
-          } finally {
-            done.incrementAndGet();
-          }
-        });
+        threads[i] =
+            new Thread(
+                () -> {
+                  try {
+                    barrier.await();
+                    for (int iters = 0; iters < itersPerThread; iters++) {
+                      Document d = new Document();
+                      d.add(new StringField("id", "1", Field.Store.NO));
+                      writer.updateDocument(new Term("id", "1"), d);
+                    }
+                  } catch (Exception e) {
+                    throw new AssertionError(e);
+                  } finally {
+                    done.incrementAndGet();
+                  }
+                });
         threads[i].start();
       }
       DirectoryReader open = DirectoryReader.open(writer.w);
