@@ -16,7 +16,6 @@
  */
 package org.apache.lucene.search;
 
-
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
@@ -27,9 +26,8 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
-
-import org.apache.lucene.analysis.MockAnalyzer;
 import org.apache.lucene.document.Document;
+import org.apache.lucene.document.Field;
 import org.apache.lucene.index.ConcurrentMergeScheduler;
 import org.apache.lucene.index.DirectoryReader;
 import org.apache.lucene.index.FilterDirectoryReader;
@@ -39,18 +37,18 @@ import org.apache.lucene.index.IndexWriter;
 import org.apache.lucene.index.IndexWriterConfig;
 import org.apache.lucene.index.LeafReader;
 import org.apache.lucene.index.LeafReaderContext;
-import org.apache.lucene.index.RandomIndexWriter;
 import org.apache.lucene.index.Term;
-import org.apache.lucene.index.ThreadedIndexingAndSearchingTestCase;
 import org.apache.lucene.store.AlreadyClosedException;
 import org.apache.lucene.store.Directory;
-import org.apache.lucene.util.LineFileDocs;
-import org.apache.lucene.util.LuceneTestCase.SuppressCodecs;
-import org.apache.lucene.util.LuceneTestCase;
+import org.apache.lucene.tests.analysis.MockAnalyzer;
+import org.apache.lucene.tests.index.RandomIndexWriter;
+import org.apache.lucene.tests.index.ThreadedIndexingAndSearchingTestCase;
+import org.apache.lucene.tests.util.LuceneTestCase;
+import org.apache.lucene.tests.util.LuceneTestCase.SuppressCodecs;
+import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.NamedThreadFactory;
-import org.apache.lucene.util.TestUtil;
 
-@SuppressCodecs({ "SimpleText", "Memory", "Direct" })
+@SuppressCodecs({"SimpleText", "Direct"})
 public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
 
   boolean warmCalled;
@@ -58,12 +56,14 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
   private SearcherLifetimeManager.Pruner pruner;
 
   public void testSearcherManager() throws Exception {
-    pruner = new SearcherLifetimeManager.PruneByAge(TEST_NIGHTLY ? TestUtil.nextInt(random(), 1, 20) : 1);
+    pruner =
+        new SearcherLifetimeManager.PruneByAge(
+            TEST_NIGHTLY ? TestUtil.nextInt(random(), 1, 20) : 1);
     runTest("TestSearcherManager");
   }
 
   @Override
-  protected IndexSearcher getFinalSearcher() throws Exception  {
+  protected IndexSearcher getFinalSearcher() throws Exception {
     if (!isNRT) {
       writer.commit();
     }
@@ -78,15 +78,16 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
 
   @Override
   protected void doAfterWriter(final ExecutorService es) throws Exception {
-    final SearcherFactory factory = new SearcherFactory() {
-      @Override
-      public IndexSearcher newSearcher(IndexReader r, IndexReader previous) throws IOException {
-        IndexSearcher s = new IndexSearcher(r, es);
-        TestSearcherManager.this.warmCalled = true;
-        s.search(new TermQuery(new Term("body", "united")), 10);
-        return s;
-      }
-    };
+    final SearcherFactory factory =
+        new SearcherFactory() {
+          @Override
+          public IndexSearcher newSearcher(IndexReader r, IndexReader previous) throws IOException {
+            IndexSearcher s = new IndexSearcher(r, es);
+            TestSearcherManager.this.warmCalled = true;
+            s.search(new TermQuery(new Term("body", "united")), 10);
+            return s;
+          }
+        };
     if (random().nextBoolean()) {
       // TODO: can we randomize the applyAllDeletes?  But
       // somehow for final searcher we must apply
@@ -107,36 +108,38 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
   @Override
   protected void doSearching(ExecutorService es, final long stopTime) throws Exception {
 
-    Thread reopenThread = new Thread() {
-      @Override
-      public void run() {
-        try {
-          if (VERBOSE) {
-            System.out.println("[" + Thread.currentThread().getName() + "]: launch reopen thread");
-          }
+    Thread reopenThread =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              if (VERBOSE) {
+                System.out.println(
+                    "[" + Thread.currentThread().getName() + "]: launch reopen thread");
+              }
 
-          while(System.currentTimeMillis() < stopTime) {
-            Thread.sleep(TestUtil.nextInt(random(), 1, 100));
-            writer.commit();
-            Thread.sleep(TestUtil.nextInt(random(), 1, 5));
-            boolean block = random().nextBoolean();
-            if (block) {
-              mgr.maybeRefreshBlocking();
-              lifetimeMGR.prune(pruner);
-            } else if (mgr.maybeRefresh()) {
-              lifetimeMGR.prune(pruner);
+              while (System.currentTimeMillis() < stopTime) {
+                Thread.sleep(TestUtil.nextInt(random(), 1, 100));
+                writer.commit();
+                Thread.sleep(TestUtil.nextInt(random(), 1, 5));
+                boolean block = random().nextBoolean();
+                if (block) {
+                  mgr.maybeRefreshBlocking();
+                  lifetimeMGR.prune(pruner);
+                } else if (mgr.maybeRefresh()) {
+                  lifetimeMGR.prune(pruner);
+                }
+              }
+            } catch (Throwable t) {
+              if (VERBOSE) {
+                System.out.println("TEST: reopen thread hit exc");
+                t.printStackTrace(System.out);
+              }
+              failed.set(true);
+              throw new RuntimeException(t);
             }
           }
-        } catch (Throwable t) {
-          if (VERBOSE) {
-            System.out.println("TEST: reopen thread hit exc");
-            t.printStackTrace(System.out);
-          }
-          failed.set(true);
-          throw new RuntimeException(t);
-        }
-      }
-      };
+        };
     reopenThread.setDaemon(true);
     reopenThread.start();
 
@@ -159,7 +162,7 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
 
     IndexSearcher s = null;
 
-    synchronized(pastSearchers) {
+    synchronized (pastSearchers) {
       while (pastSearchers.size() != 0 && random().nextDouble() < 0.25) {
         // 1/4 of the time pull an old searcher, ie, simulate
         // a user doing a follow-on action on a previous
@@ -180,7 +183,7 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
       s = mgr.acquire();
       if (s.getIndexReader().numDocs() != 0) {
         Long token = lifetimeMGR.record(s);
-        synchronized(pastSearchers) {
+        synchronized (pastSearchers) {
           if (!pastSearchers.contains(token)) {
             pastSearchers.add(token);
           }
@@ -209,31 +212,41 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
   public void testIntermediateClose() throws IOException, InterruptedException {
     Directory dir = newDirectory();
     // Test can deadlock if we use SMS:
-    IndexWriter writer = new IndexWriter(dir, newIndexWriterConfig(
-        new MockAnalyzer(random())).setMergeScheduler(new ConcurrentMergeScheduler()));
+    IndexWriter writer =
+        new IndexWriter(
+            dir,
+            newIndexWriterConfig(new MockAnalyzer(random()))
+                .setMergeScheduler(new ConcurrentMergeScheduler()));
     writer.addDocument(new Document());
     writer.commit();
     final CountDownLatch awaitEnterWarm = new CountDownLatch(1);
     final CountDownLatch awaitClose = new CountDownLatch(1);
     final AtomicBoolean triedReopen = new AtomicBoolean(false);
-    final ExecutorService es = random().nextBoolean() ? null : Executors.newCachedThreadPool(new NamedThreadFactory("testIntermediateClose"));
-    final SearcherFactory factory = new SearcherFactory() {
-      @Override
-      public IndexSearcher newSearcher(IndexReader r, IndexReader previous) {
-        try {
-          if (triedReopen.get()) {
-            awaitEnterWarm.countDown();
-            awaitClose.await();
+    final ExecutorService es =
+        random().nextBoolean()
+            ? null
+            : Executors.newCachedThreadPool(new NamedThreadFactory("testIntermediateClose"));
+    final SearcherFactory factory =
+        new SearcherFactory() {
+          @Override
+          public IndexSearcher newSearcher(IndexReader r, IndexReader previous) {
+            try {
+              if (triedReopen.get()) {
+                awaitEnterWarm.countDown();
+                awaitClose.await();
+              }
+            } catch (
+                @SuppressWarnings("unused")
+                InterruptedException e) {
+              //
+            }
+            return new IndexSearcher(r, es);
           }
-        } catch (InterruptedException e) {
-          //
-        }
-        return new IndexSearcher(r, es);
-      }
-    };
-    final SearcherManager searcherManager = random().nextBoolean() 
-        ? new SearcherManager(dir, factory) 
-      : new SearcherManager(writer, random().nextBoolean(), false, factory);
+        };
+    final SearcherManager searcherManager =
+        random().nextBoolean()
+            ? new SearcherManager(dir, factory)
+            : new SearcherManager(writer, random().nextBoolean(), false, factory);
     if (VERBOSE) {
       System.out.println("sm created");
     }
@@ -247,30 +260,33 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
     writer.commit();
     final AtomicBoolean success = new AtomicBoolean(false);
     final Throwable[] exc = new Throwable[1];
-    Thread thread = new Thread(new Runnable() {
-      @Override
-      public void run() {
-        try {
-          triedReopen.set(true);
-          if (VERBOSE) {
-            System.out.println("NOW call maybeRefresh");
-          }
-          searcherManager.maybeRefresh();
-          success.set(true);
-        } catch (AlreadyClosedException e) {
-          // expected
-        } catch (Throwable e) {
-          if (VERBOSE) {
-            System.out.println("FAIL: unexpected exc");
-            e.printStackTrace(System.out);
-          }
-          exc[0] = e;
-          // use success as the barrier here to make sure we see the write
-          success.set(false);
-
-        }
-      }
-    });
+    Thread thread =
+        new Thread(
+            new Runnable() {
+              @Override
+              public void run() {
+                try {
+                  triedReopen.set(true);
+                  if (VERBOSE) {
+                    System.out.println("NOW call maybeRefresh");
+                  }
+                  searcherManager.maybeRefresh();
+                  success.set(true);
+                } catch (
+                    @SuppressWarnings("unused")
+                    AlreadyClosedException e) {
+                  // expected
+                } catch (Throwable e) {
+                  if (VERBOSE) {
+                    System.out.println("FAIL: unexpected exc");
+                    e.printStackTrace(System.out);
+                  }
+                  exc[0] = e;
+                  // use success as the barrier here to make sure we see the write
+                  success.set(false);
+                }
+              }
+            });
     thread.start();
     if (VERBOSE) {
       System.out.println("THREAD started");
@@ -282,9 +298,11 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
     searcherManager.close();
     awaitClose.countDown();
     thread.join();
-    expectThrows(AlreadyClosedException.class, () -> {
-      searcherManager.acquire();
-    });
+    expectThrows(
+        AlreadyClosedException.class,
+        () -> {
+          searcherManager.acquire();
+        });
     assertFalse(success.get());
     assertTrue(triedReopen.get());
     assertNull("" + exc[0], exc[0]);
@@ -295,7 +313,7 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
       es.awaitTermination(1, TimeUnit.SECONDS);
     }
   }
-  
+
   public void testCloseTwice() throws Exception {
     // test that we can close SM twice (per Closeable's contract).
     Directory dir = newDirectory();
@@ -308,8 +326,12 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
 
   public void testReferenceDecrementIllegally() throws Exception {
     Directory dir = newDirectory();
-    IndexWriter writer = new IndexWriter(dir, newIndexWriterConfig(
-        new MockAnalyzer(random())).setMergeScheduler(new ConcurrentMergeScheduler()));
+    IndexWriter writer =
+        new IndexWriter(
+            dir,
+            newIndexWriterConfig(new MockAnalyzer(random()))
+                .setMergeScheduler(new ConcurrentMergeScheduler()));
+    @SuppressWarnings("resource")
     SearcherManager sm = new SearcherManager(writer, false, false, new SearcherFactory());
     writer.addDocument(new Document());
     writer.commit();
@@ -320,39 +342,43 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
     sm.release(acquire);
     sm.release(acquire2);
 
-
     acquire = sm.acquire();
     acquire.getIndexReader().decRef();
     sm.release(acquire);
-    expectThrows(IllegalStateException.class, () -> {
-      sm.acquire();
-    });
+    expectThrows(
+        IllegalStateException.class,
+        () -> {
+          sm.acquire();
+        });
 
     // sm.close(); -- already closed
     writer.close();
     dir.close();
   }
 
-
   public void testEnsureOpen() throws Exception {
     Directory dir = newDirectory();
     new IndexWriter(dir, new IndexWriterConfig(null)).close();
     SearcherManager sm = new SearcherManager(dir, null);
     IndexSearcher s = sm.acquire();
     sm.close();
-    
+
     // this should succeed;
     sm.release(s);
-    
+
     // this should fail
-    expectThrows(AlreadyClosedException.class, () -> {
-      sm.acquire();
-    });
-    
+    expectThrows(
+        AlreadyClosedException.class,
+        () -> {
+          sm.acquire();
+        });
+
     // this should fail
-    expectThrows(AlreadyClosedException.class, () -> {
-      sm.maybeRefresh();
-    });
+    expectThrows(
+        AlreadyClosedException.class,
+        () -> {
+          sm.maybeRefresh();
+        });
 
     dir.close();
   }
@@ -362,17 +388,18 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
     IndexWriter iw = new IndexWriter(dir, new IndexWriterConfig(null));
     final AtomicBoolean afterRefreshCalled = new AtomicBoolean(false);
     SearcherManager sm = new SearcherManager(iw, false, false, new SearcherFactory());
-    sm.addListener(new ReferenceManager.RefreshListener() {
-      @Override
-      public void beforeRefresh() {
-      }
-      @Override
-      public void afterRefresh(boolean didRefresh) {
-        if (didRefresh) {
-          afterRefreshCalled.set(true);
-        }
-      }
-    });
+    sm.addListener(
+        new ReferenceManager.RefreshListener() {
+          @Override
+          public void beforeRefresh() {}
+
+          @Override
+          public void afterRefresh(boolean didRefresh) {
+            if (didRefresh) {
+              afterRefreshCalled.set(true);
+            }
+          }
+        });
     iw.addDocument(new Document());
     iw.commit();
     assertFalse(afterRefreshCalled.get());
@@ -391,50 +418,56 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
 
     final IndexReader other = DirectoryReader.open(dir);
 
-    final SearcherFactory theEvilOne = new SearcherFactory() {
-      @Override
-      public IndexSearcher newSearcher(IndexReader ignored, IndexReader previous) {
-        return LuceneTestCase.newSearcher(other);
-      }
-      };
+    final SearcherFactory theEvilOne =
+        new SearcherFactory() {
+          @Override
+          public IndexSearcher newSearcher(IndexReader ignored, IndexReader previous) {
+            return LuceneTestCase.newSearcher(other);
+          }
+        };
 
-    expectThrows(IllegalStateException.class, () -> {
-      new SearcherManager(dir, theEvilOne);
-    });
-    expectThrows(IllegalStateException.class, () -> {
-      new SearcherManager(w.w, random.nextBoolean(), false, theEvilOne);
-    });
+    expectThrows(
+        IllegalStateException.class,
+        () -> {
+          new SearcherManager(dir, theEvilOne);
+        });
+    expectThrows(
+        IllegalStateException.class,
+        () -> {
+          new SearcherManager(w.w, random.nextBoolean(), false, theEvilOne);
+        });
     w.close();
     other.close();
     dir.close();
   }
-  
+
   public void testMaybeRefreshBlockingLock() throws Exception {
     // make sure that maybeRefreshBlocking releases the lock, otherwise other
     // threads cannot obtain it.
     final Directory dir = newDirectory();
     final RandomIndexWriter w = new RandomIndexWriter(random(), dir);
     w.close();
-    
+
     final SearcherManager sm = new SearcherManager(dir, null);
-    
-    Thread t = new Thread() {
-      @Override
-      public void run() {
-        try {
-          // this used to not release the lock, preventing other threads from obtaining it.
-          sm.maybeRefreshBlocking();
-        } catch (Exception e) {
-          throw new RuntimeException(e);
-        }
-      }
-    };
+
+    Thread t =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              // this used to not release the lock, preventing other threads from obtaining it.
+              sm.maybeRefreshBlocking();
+            } catch (Exception e) {
+              throw new RuntimeException(e);
+            }
+          }
+        };
     t.start();
     t.join();
-    
+
     // if maybeRefreshBlocking didn't release the lock, this will fail.
     assertTrue("failde to obtain the refreshLock!", sm.maybeRefresh());
-    
+
     sm.close();
     dir.close();
   }
@@ -457,15 +490,16 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
 
   private static class MyFilterDirectoryReader extends FilterDirectoryReader {
     public MyFilterDirectoryReader(DirectoryReader in) throws IOException {
-      super(in, 
-            new FilterDirectoryReader.SubReaderWrapper() {
-              @Override
-              public LeafReader wrap(LeafReader reader) {
-                FilterLeafReader wrapped = new MyFilterLeafReader(reader);
-                assertEquals(reader, wrapped.getDelegate());
-                return wrapped;
-              }
-            });
+      super(
+          in,
+          new FilterDirectoryReader.SubReaderWrapper() {
+            @Override
+            public LeafReader wrap(LeafReader reader) {
+              FilterLeafReader wrapped = new MyFilterLeafReader(reader);
+              assertEquals(reader, wrapped.getDelegate());
+              return wrapped;
+            }
+          });
     }
 
     @Override
@@ -490,7 +524,7 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
     assertEquals(FilterDirectoryReader.unwrap(nrtReader), FilterDirectoryReader.unwrap(reader));
 
     SearcherManager mgr = new SearcherManager(reader, null);
-    for(int i=0;i<10;i++) {
+    for (int i = 0; i < 10; i++) {
       w.addDocument(new Document());
       mgr.maybeRefresh();
       IndexSearcher s = mgr.acquire();
@@ -516,8 +550,10 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
       IndexReader lastReader = null;
       IndexReader lastPreviousReader = null;
       int called = 0;
+
       @Override
-      public IndexSearcher newSearcher(IndexReader reader, IndexReader previousReader) throws IOException {
+      public IndexSearcher newSearcher(IndexReader reader, IndexReader previousReader)
+          throws IOException {
         called++;
         lastReader = reader;
         lastPreviousReader = previousReader;
@@ -556,128 +592,142 @@ public class TestSearcherManager extends ThreadedIndexingAndSearchingTestCase {
     AtomicReference<IndexWriter> writerRef = new AtomicReference<>();
     final MockAnalyzer analyzer = new MockAnalyzer(random());
     analyzer.setMaxTokenLength(IndexWriter.MAX_TERM_LENGTH);
-    writerRef.set(new IndexWriter(dir, newIndexWriterConfig(analyzer)));
+    writerRef.set(new IndexWriter(dir, ensureSaneIWCOnNightly(newIndexWriterConfig(analyzer))));
 
     AtomicReference<SearcherManager> mgrRef = new AtomicReference<>();
     mgrRef.set(new SearcherManager(writerRef.get(), null));
     final AtomicBoolean stop = new AtomicBoolean();
 
-    Thread indexThread = new Thread() {
-        @Override
-        public void run() {
-          try {
-            LineFileDocs docs = new LineFileDocs(random());
-            long runTimeSec = TEST_NIGHTLY ? atLeast(10) : atLeast(2);
-            long endTime = System.nanoTime() + runTimeSec * 1000000000;
-            while (System.nanoTime() < endTime) {
-              IndexWriter w = writerRef.get();
-              w.addDocument(docs.nextDoc());
-              if (random().nextInt(1000) == 17) {
-                if (random().nextBoolean()) {
-                  w.close();
-                } else {
-                  w.rollback();
-                }
-                writerRef.set(new IndexWriter(dir, newIndexWriterConfig(analyzer)));
-              }
-            }
-            docs.close();
-            if (VERBOSE) {
-              System.out.println("TEST: index count=" + writerRef.get().getDocStats().maxDoc);
-            }
-          } catch (IOException ioe) {
-            throw new RuntimeException(ioe);
-          } finally {
-            stop.set(true);
-          }
-        }
-      };
-
-    Thread searchThread = new Thread() {
-        @Override
-        public void run() {
-          try {
-            long totCount = 0;
-            while (stop.get() == false) {
-              SearcherManager mgr = mgrRef.get();
-              if (mgr != null) {
-                IndexSearcher searcher;
-                try {
-                  searcher = mgr.acquire();
-                } catch (AlreadyClosedException ace) {
-                  // ok
-                  continue;
-                }
-                totCount += searcher.getIndexReader().maxDoc();
-                mgr.release(searcher);
-              }
-            }
-            if (VERBOSE) {
-              System.out.println("TEST: search totCount=" + totCount);
-            }
-          } catch (IOException ioe) {
-            throw new RuntimeException(ioe);
-          }
-        }
-      };
-
-    Thread refreshThread = new Thread() {
-        @Override
-        public void run() {
-          try {
-            int refreshCount = 0;
-            int aceCount = 0;
-            while (stop.get() == false) {
-              SearcherManager mgr = mgrRef.get();
-              if (mgr != null) {
-                refreshCount++;
-                try {
-                  mgr.maybeRefreshBlocking();
-                } catch (AlreadyClosedException ace) {
-                  // ok
-                  aceCount++;
-                  continue;
+    Thread indexThread =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              int numDocs = TEST_NIGHTLY ? atLeast(20000) : atLeast(200);
+              for (int i = 0; i < numDocs; i++) {
+                IndexWriter w = writerRef.get();
+                Document doc = new Document();
+                doc.add(
+                    newTextField(
+                        "field",
+                        TestUtil.randomAnalysisString(random(), 256, false),
+                        Field.Store.YES));
+                w.addDocument(doc);
+                if (random().nextInt(1000) == 17) {
+                  if (random().nextBoolean()) {
+                    w.close();
+                  } else {
+                    w.rollback();
+                  }
+                  writerRef.set(
+                      new IndexWriter(dir, ensureSaneIWCOnNightly(newIndexWriterConfig(analyzer))));
                 }
               }
+              if (VERBOSE) {
+                System.out.println("TEST: index count=" + writerRef.get().getDocStats().maxDoc);
+              }
+            } catch (IOException ioe) {
+              throw new RuntimeException(ioe);
+            } finally {
+              stop.set(true);
             }
-            if (VERBOSE) {
-              System.out.println("TEST: refresh count=" + refreshCount + " aceCount=" + aceCount);
-            }
-          } catch (IOException ioe) {
-            throw new RuntimeException(ioe);
           }
-        }
-      };
+        };
 
-    Thread closeThread = new Thread() {
-        @Override
-        public void run() {
-          try {
-            int closeCount = 0;
-            int aceCount = 0;
-            while (stop.get() == false) {
-              SearcherManager mgr = mgrRef.get();
-              assert mgr != null;
-              mgr.close();
-              closeCount++;
+    Thread searchThread =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              long totCount = 0;
               while (stop.get() == false) {
-                try {
-                  mgrRef.set(new SearcherManager(writerRef.get(), null));
-                  break;
-                } catch (AlreadyClosedException ace) {
-                  // ok
-                  aceCount++;
+                SearcherManager mgr = mgrRef.get();
+                if (mgr != null) {
+                  IndexSearcher searcher;
+                  try {
+                    searcher = mgr.acquire();
+                  } catch (
+                      @SuppressWarnings("unused")
+                      AlreadyClosedException ace) {
+                    // ok
+                    continue;
+                  }
+                  totCount += searcher.getIndexReader().maxDoc();
+                  mgr.release(searcher);
                 }
               }
+              if (VERBOSE) {
+                System.out.println("TEST: search totCount=" + totCount);
+              }
+            } catch (IOException ioe) {
+              throw new RuntimeException(ioe);
             }
-            if (VERBOSE) {
-              System.out.println("TEST: close count=" + closeCount + " aceCount=" + aceCount);
-            }
-          } catch (IOException ioe) {
-            throw new RuntimeException(ioe);
           }
-        }
-      };
+        };
+
+    Thread refreshThread =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              int refreshCount = 0;
+              int aceCount = 0;
+              while (stop.get() == false) {
+                SearcherManager mgr = mgrRef.get();
+                if (mgr != null) {
+                  refreshCount++;
+                  try {
+                    mgr.maybeRefreshBlocking();
+                  } catch (
+                      @SuppressWarnings("unused")
+                      AlreadyClosedException ace) {
+                    // ok
+                    aceCount++;
+                    continue;
+                  }
+                }
+              }
+              if (VERBOSE) {
+                System.out.println("TEST: refresh count=" + refreshCount + " aceCount=" + aceCount);
+              }
+            } catch (IOException ioe) {
+              throw new RuntimeException(ioe);
+            }
+          }
+        };
+
+    Thread closeThread =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              int closeCount = 0;
+              int aceCount = 0;
+              while (stop.get() == false) {
+                SearcherManager mgr = mgrRef.get();
+                assert mgr != null;
+                mgr.close();
+                closeCount++;
+                while (stop.get() == false) {
+                  try {
+                    mgrRef.set(new SearcherManager(writerRef.get(), null));
+                    break;
+                  } catch (
+                      @SuppressWarnings("unused")
+                      AlreadyClosedException ace) {
+                    // ok
+                    aceCount++;
+                  }
+                }
+              }
+              if (VERBOSE) {
+                System.out.println("TEST: close count=" + closeCount + " aceCount=" + aceCount);
+              }
+            } catch (IOException ioe) {
+              throw new RuntimeException(ioe);
+            }
+          }
+        };
 
     indexThread.start();
     searchThread.start();
