@@ -17,6 +17,7 @@
 
 package org.apache.lucene.replicator.nrt;
 
+import com.carrotsearch.randomizedtesting.SeedUtils;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
@@ -28,21 +29,18 @@ import java.util.Locale;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.regex.Pattern;
-
 import org.apache.lucene.document.Document;
 import org.apache.lucene.index.IndexWriter;
 import org.apache.lucene.store.FSDirectory;
 import org.apache.lucene.store.LockObtainFailedException;
+import org.apache.lucene.tests.util.LineFileDocs;
+import org.apache.lucene.tests.util.LuceneTestCase;
+import org.apache.lucene.tests.util.LuceneTestCase.SuppressCodecs;
+import org.apache.lucene.tests.util.LuceneTestCase.SuppressSysoutChecks;
+import org.apache.lucene.tests.util.TestRuleIgnoreTestSuites;
+import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.IOUtils;
-import org.apache.lucene.util.LineFileDocs;
-import org.apache.lucene.util.LuceneTestCase.SuppressCodecs;
-import org.apache.lucene.util.LuceneTestCase.SuppressSysoutChecks;
-import org.apache.lucene.util.LuceneTestCase;
 import org.apache.lucene.util.SuppressForbidden;
-import org.apache.lucene.util.TestRuleIgnoreTestSuites;
-import org.apache.lucene.util.TestUtil;
-
-import com.carrotsearch.randomizedtesting.SeedUtils;
 
 // MockRandom's .sd file has no index header/footer:
 @SuppressCodecs({"MockRandom", "Direct", "SimpleText"})
@@ -59,14 +57,17 @@ public class TestNRTReplication extends LuceneTestCase {
 
   /** Launches a child "server" (separate JVM), which is either primary or replica node */
   @SuppressForbidden(reason = "ProcessBuilder requires java.io.File for CWD")
-  private NodeProcess startNode(int primaryTCPPort, final int id, Path indexPath, long forcePrimaryVersion, boolean willCrash) throws IOException {
+  private NodeProcess startNode(
+      int primaryTCPPort, final int id, Path indexPath, long forcePrimaryVersion, boolean willCrash)
+      throws IOException {
     List<String> cmd = new ArrayList<>();
 
-    cmd.add(System.getProperty("java.home") 
-        + System.getProperty("file.separator")
-        + "bin"
-        + System.getProperty("file.separator")
-        + "java");
+    cmd.add(
+        System.getProperty("java.home")
+            + System.getProperty("file.separator")
+            + "bin"
+            + System.getProperty("file.separator")
+            + "java");
     cmd.add("-Xmx512m");
 
     long myPrimaryGen;
@@ -102,8 +103,9 @@ public class TestNRTReplication extends LuceneTestCase {
     long seed = random().nextLong() * nodeStartCounter.incrementAndGet();
     cmd.add("-Dtests.seed=" + SeedUtils.formatSeed(seed));
     cmd.add("-ea");
-    cmd.add("-cp");
-    cmd.add(System.getProperty("java.class.path"));
+
+    cmd.addAll(getJvmForkArguments());
+
     cmd.add("org.junit.runner.JUnitCore");
     cmd.add(TestSimpleServer.class.getName());
 
@@ -127,7 +129,6 @@ public class TestNRTReplication extends LuceneTestCase {
     long initCommitVersion = -1;
     long initInfosVersion = -1;
     Pattern logTimeStart = Pattern.compile("^[0-9\\.]+s .*");
-    boolean sawExistingSegmentsFile = false;
 
     while (true) {
       String l = r.readLine();
@@ -161,7 +162,6 @@ public class TestNRTReplication extends LuceneTestCase {
       } else if (l.startsWith("NODE STARTED")) {
         break;
       } else if (l.contains("replica cannot start: existing segments file=")) {
-        sawExistingSegmentsFile = true;
       }
     }
 
@@ -169,30 +169,52 @@ public class TestNRTReplication extends LuceneTestCase {
 
     // Baby sits the child process, pulling its stdout and printing to our stdout:
     AtomicBoolean nodeClosing = new AtomicBoolean();
-    Thread pumper = ThreadPumper.start(
-                                       new Runnable() {
-                                         @Override
-                                         public void run() {
-                                           message("now wait for process " + p);
-                                           try {
-                                             p.waitFor();
-                                           } catch (Throwable t) {
-                                             throw new RuntimeException(t);
-                                           }
+    Thread pumper =
+        ThreadPumper.start(
+            new Runnable() {
+              @Override
+              public void run() {
+                message("now wait for process " + p);
+                try {
+                  p.waitFor();
+                } catch (Throwable t) {
+                  throw new RuntimeException(t);
+                }
 
-                                           message("done wait for process " + p);
-                                           int exitValue = p.exitValue();
-                                           message("exit value=" + exitValue + " willCrash=" + finalWillCrash);
-                                           if (exitValue != 0 && finalWillCrash == false) {
-                                             // should fail test
-                                             throw new RuntimeException("node " + id + " process had unexpected non-zero exit status=" + exitValue);
-                                           }
-                                         }
-                                       }, r, System.out, null, nodeClosing);
+                message("done wait for process " + p);
+                int exitValue = p.exitValue();
+                message("exit value=" + exitValue + " willCrash=" + finalWillCrash);
+                if (exitValue != 0 && finalWillCrash == false) {
+                  // should fail test
+                  throw new RuntimeException(
+                      "node " + id + " process had unexpected non-zero exit status=" + exitValue);
+                }
+              }
+            },
+            r,
+            System.out,
+            null,
+            nodeClosing);
     pumper.setName("pump" + id);
 
-    message("top: node=" + id + " started at tcpPort=" + tcpPort + " initCommitVersion=" + initCommitVersion + " initInfosVersion=" + initInfosVersion);
-    return new NodeProcess(p, id, tcpPort, pumper, primaryTCPPort == -1, initCommitVersion, initInfosVersion, nodeClosing);
+    message(
+        "top: node="
+            + id
+            + " started at tcpPort="
+            + tcpPort
+            + " initCommitVersion="
+            + initCommitVersion
+            + " initInfosVersion="
+            + initInfosVersion);
+    return new NodeProcess(
+        p,
+        id,
+        tcpPort,
+        pumper,
+        primaryTCPPort == -1,
+        initCommitVersion,
+        initInfosVersion,
+        nodeClosing);
   }
 
   @Override
@@ -225,7 +247,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     Connection primaryC = new Connection(primary.tcpPort);
     primaryC.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-    for(int i=0;i<10;i++) {
+    for (int i = 0; i < 10; i++) {
       Document doc = docs.nextDoc();
       primary.addOrUpdateDocument(primaryC, doc, false);
     }
@@ -243,7 +265,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Delete all docs from primary
     if (random().nextBoolean()) {
       // Inefficiently:
-      for(int id=0;id<10;id++) {
+      for (int id = 0; id < 10; id++) {
         primary.deleteDocument(primaryC, Integer.toString(id));
       }
     } else {
@@ -253,7 +275,7 @@ public class TestNRTReplication extends LuceneTestCase {
 
     // Replica still shows 10 docs:
     assertVersionAndHits(replica, primaryVersion1, 10);
-    
+
     // Refresh primary, which also pushes to replica:
     long primaryVersion2 = primary.flush(0);
     assertTrue(primaryVersion2 > primaryVersion1);
@@ -262,7 +284,7 @@ public class TestNRTReplication extends LuceneTestCase {
     waitForVersionAndHits(replica, primaryVersion2, 0);
 
     // Index 10 docs again:
-    for(int i=0;i<10;i++) {
+    for (int i = 0; i < 10; i++) {
       Document doc = docs.nextDoc();
       primary.addOrUpdateDocument(primaryC, doc, false);
     }
@@ -295,7 +317,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     Connection primaryC = new Connection(primary.tcpPort);
     primaryC.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-    for(int i=0;i<10;i++) {
+    for (int i = 0; i < 10; i++) {
       Document doc = docs.nextDoc();
       primary.addOrUpdateDocument(primaryC, doc, false);
     }
@@ -305,7 +327,7 @@ public class TestNRTReplication extends LuceneTestCase {
     assertTrue(primaryVersion1 > 0);
 
     // Index 10 more docs into primary:
-    for(int i=0;i<10;i++) {
+    for (int i = 0; i < 10; i++) {
       Document doc = docs.nextDoc();
       primary.addOrUpdateDocument(primaryC, doc, false);
     }
@@ -332,7 +354,6 @@ public class TestNRTReplication extends LuceneTestCase {
   // Start up, index 10 docs, replicate, but crash and restart the replica without committing it:
   @Nightly
   public void testReplicaCrashNoCommit() throws Exception {
-
     Path primaryPath = createTempDir("primary");
     NodeProcess primary = startNode(-1, 0, primaryPath, -1, false);
 
@@ -345,7 +366,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -391,7 +412,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -418,7 +439,8 @@ public class TestNRTReplication extends LuceneTestCase {
     primary.close();
   }
 
-  // Start up, index 10 docs, replicate, commit, crash, index more docs, replicate, then restart the replica
+  // Start up, index 10 docs, replicate, commit, crash, index more docs, replicate, then restart the
+  // replica
   @Nightly
   public void testIndexingWhileReplicaIsDown() throws Exception {
 
@@ -434,7 +456,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -456,7 +478,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 10 more docs, while replica is down
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -482,7 +504,7 @@ public class TestNRTReplication extends LuceneTestCase {
     replica.close();
     primary.close();
   }
- 
+
   // Crash primary and promote a replica
   @Nightly
   public void testCrashPrimary1() throws Exception {
@@ -499,7 +521,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -520,7 +542,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Promote replica:
     replica.commit();
     replica.close();
-    
+
     primary = startNode(-1, 1, path2, -1, false);
 
     // Should still see 10 docs:
@@ -545,7 +567,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -563,7 +585,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 10 docs, but crash before replicating or committing:
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -580,7 +602,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 10 more docs
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -597,7 +619,8 @@ public class TestNRTReplication extends LuceneTestCase {
     replica.close();
   }
 
-  // Crash primary and then restart it, while a replica node is down, then bring replica node back up and make sure it properly "unforks" itself
+  // Crash primary and then restart it, while a replica node is down, then bring replica node back
+  // up and make sure it properly "unforks" itself
   @Nightly
   public void testCrashPrimary3() throws Exception {
 
@@ -612,7 +635,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 10 docs into primary:
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -630,7 +653,8 @@ public class TestNRTReplication extends LuceneTestCase {
     replica.close();
     primary.crash();
 
-    // At this point replica is "in the future": it has 10 docs committed, but the primary crashed before committing so it has 0 docs
+    // At this point replica is "in the future": it has 10 docs committed, but the primary crashed
+    // before committing so it has 0 docs
 
     // Restart primary:
     primary = startNode(-1, 0, path1, -1, true);
@@ -638,7 +662,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 20 docs into primary:
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<20;i++) {
+      for (int i = 0; i < 20; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -647,7 +671,8 @@ public class TestNRTReplication extends LuceneTestCase {
     // Flush primary, but there are no replicas to sync to:
     long primaryVersion2 = primary.flush(0);
 
-    // Now restart replica, which on init should detect on a "lost branch" because its 10 docs that were committed came from a different
+    // Now restart replica, which on init should detect on a "lost branch" because its 10 docs that
+    // were committed came from a different
     // primary node:
     replica = startNode(primary.tcpPort, 1, path2, -1, true);
 
@@ -672,7 +697,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<100;i++) {
+      for (int i = 0; i < 100; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -707,10 +732,15 @@ public class TestNRTReplication extends LuceneTestCase {
 
   private void assertWriteLockHeld(Path path) throws Exception {
     try (FSDirectory dir = FSDirectory.open(path)) {
-      expectThrows(LockObtainFailedException.class, () -> {dir.obtainLock(IndexWriter.WRITE_LOCK_NAME);});
+      expectThrows(
+          LockObtainFailedException.class,
+          () -> {
+            dir.obtainLock(IndexWriter.WRITE_LOCK_NAME);
+          });
     }
   }
 
+  @Nightly
   public void testCrashReplica() throws Exception {
 
     Path path1 = createTempDir("1");
@@ -727,7 +757,7 @@ public class TestNRTReplication extends LuceneTestCase {
     LineFileDocs docs = new LineFileDocs(random());
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -747,11 +777,11 @@ public class TestNRTReplication extends LuceneTestCase {
 
     // Lots of new flushes while replica is down:
     long primaryVersion2 = 0;
-    for(int iter=0;iter<10;iter++) {
+    for (int iter = 0; iter < 10; iter++) {
       // Index 10 docs into primary:
       try (Connection c = new Connection(primary.tcpPort)) {
         c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-        for(int i=0;i<10;i++) {
+        for (int i = 0; i < 10; i++) {
           Document doc = docs.nextDoc();
           primary.addOrUpdateDocument(c, doc, false);
         }
@@ -792,10 +822,10 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 50 docs into primary:
     LineFileDocs docs = new LineFileDocs(random());
     long primaryVersion1 = 0;
-    for (int iter=0;iter<5;iter++) {
+    for (int iter = 0; iter < 5; iter++) {
       try (Connection c = new Connection(primary.tcpPort)) {
         c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-        for(int i=0;i<10;i++) {
+        for (int i = 0; i < 10; i++) {
           Document doc = docs.nextDoc();
           primary.addOrUpdateDocument(c, doc, false);
         }
@@ -817,7 +847,7 @@ public class TestNRTReplication extends LuceneTestCase {
     // Index 10 more docs, but don't sync to replicas:
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_INDEXING);
-      for(int i=0;i<10;i++) {
+      for (int i = 0; i < 10; i++) {
         Document doc = docs.nextDoc();
         primary.addOrUpdateDocument(c, doc, false);
       }
@@ -834,7 +864,7 @@ public class TestNRTReplication extends LuceneTestCase {
     replica2 = startNode(primary.tcpPort, 2, path3, -1, true);
 
     // Only 50 because we didn't commit primary before the crash:
-    
+
     // It's -1 because it's unpredictable how IW changes segments version on init:
     assertVersionAndHits(primary, -1, 50);
     assertVersionAndHits(replica1, primary.initInfosVersion, 50);
@@ -847,11 +877,12 @@ public class TestNRTReplication extends LuceneTestCase {
   }
 
   /** Tell primary current replicas. */
-  private void sendReplicasToPrimary(NodeProcess primary, NodeProcess... replicas) throws IOException {
+  private void sendReplicasToPrimary(NodeProcess primary, NodeProcess... replicas)
+      throws IOException {
     try (Connection c = new Connection(primary.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_SET_REPLICAS);
       c.out.writeVInt(replicas.length);
-      for(int id=0;id<replicas.length;id++) {
+      for (int id = 0; id < replicas.length; id++) {
         NodeProcess replica = replicas[id];
         c.out.writeVInt(replica.id);
         c.out.writeVInt(replica.tcpPort);
@@ -861,9 +892,12 @@ public class TestNRTReplication extends LuceneTestCase {
     }
   }
 
-  /** Verifies this node is currently searching the specified version with the specified total hit count, or that it eventually does when
-   *  keepTrying is true. */
-  private void assertVersionAndHits(NodeProcess node, long expectedVersion, int expectedHitCount) throws Exception {
+  /**
+   * Verifies this node is currently searching the specified version with the specified total hit
+   * count, or that it eventually does when keepTrying is true.
+   */
+  private void assertVersionAndHits(NodeProcess node, long expectedVersion, int expectedHitCount)
+      throws Exception {
     try (Connection c = new Connection(node.tcpPort)) {
       c.out.writeByte(SimplePrimaryNode.CMD_SEARCH_ALL);
       c.flush();
@@ -876,7 +910,8 @@ public class TestNRTReplication extends LuceneTestCase {
     }
   }
 
-  private void waitForVersionAndHits(NodeProcess node, long expectedVersion, int expectedHitCount) throws Exception {
+  private void waitForVersionAndHits(NodeProcess node, long expectedVersion, int expectedHitCount)
+      throws Exception {
     try (Connection c = new Connection(node.tcpPort)) {
       while (true) {
         c.out.writeByte(SimplePrimaryNode.CMD_SEARCH_ALL);
@@ -897,10 +932,12 @@ public class TestNRTReplication extends LuceneTestCase {
 
   static void message(String message) {
     long now = System.nanoTime();
-    System.out.println(String.format(Locale.ROOT,
-                                     "%5.3fs       :     parent [%11s] %s",
-                                     (now-Node.globalStartNS)/1000000000.,
-                                     Thread.currentThread().getName(),
-                                     message));
+    System.out.println(
+        String.format(
+            Locale.ROOT,
+            "%5.3fs       :     parent [%11s] %s",
+            (now - Node.globalStartNS) / 1000000000.,
+            Thread.currentThread().getName(),
+            message));
   }
 }
